@@ -1,4 +1,4 @@
-use super::{AtRule, Comment, CssString, MediaRule, Rule, Value};
+use super::{AtRule, Comment, MediaRule, Rule, Value};
 use crate::output::CssBuf;
 use std::io::{self, Write};
 
@@ -22,60 +22,60 @@ pub enum Item {
 impl Item {
     pub(crate) fn write(&self, buf: &mut CssBuf) -> io::Result<()> {
         match self {
-            Item::Comment(comment) => comment.write(buf),
-            Item::Import(import) => import.write(buf)?,
-            Item::Rule(rule) => rule.write(buf)?,
-            Item::MediaRule(rule) => rule.write(buf)?,
-            Item::AtRule(atrule) => atrule.write(buf)?,
-            Item::Separator => buf.opt_nl(),
+            Self::Comment(comment) => comment.write(buf),
+            Self::Import(import) => import.write(buf)?,
+            Self::Rule(rule) => rule.write(buf)?,
+            Self::MediaRule(rule) => rule.write(buf)?,
+            Self::AtRule(atrule) => atrule.write(buf)?,
+            Self::Separator => buf.opt_nl(),
         }
         Ok(())
     }
 }
 
 impl From<Comment> for Item {
-    fn from(comment: Comment) -> Item {
-        Item::Comment(comment)
+    fn from(comment: Comment) -> Self {
+        Self::Comment(comment)
     }
 }
 impl From<Import> for Item {
-    fn from(import: Import) -> Item {
-        Item::Import(import)
+    fn from(import: Import) -> Self {
+        Self::Import(import)
     }
 }
 impl From<Rule> for Item {
-    fn from(rule: Rule) -> Item {
-        Item::Rule(rule)
+    fn from(rule: Rule) -> Self {
+        Self::Rule(rule)
     }
 }
 impl From<AtRule> for Item {
     fn from(value: AtRule) -> Self {
-        Item::AtRule(value)
+        Self::AtRule(value)
     }
 }
 impl From<MediaRule> for Item {
     fn from(value: MediaRule) -> Self {
-        Item::MediaRule(value)
+        Self::MediaRule(value)
     }
 }
 
 /// An `@import` rule in css.
 #[derive(Clone, Debug)]
 pub struct Import {
-    name: CssString,
+    name: Value,
     args: Value,
 }
 
 impl Import {
     /// Create a new `@import`.
-    pub fn new(name: CssString, args: Value) -> Self {
-        Import { name, args }
+    pub fn new(name: Value, args: Value) -> Self {
+        Self { name, args }
     }
 
     /// Write this comment to a css output buffer.
     pub(crate) fn write(&self, buf: &mut CssBuf) -> io::Result<()> {
         buf.do_indent_no_nl();
-        write!(buf, "@import {}", self.name)?;
+        write!(buf, "@import {}", &self.name.format(buf.format()))?;
         if !self.args.is_null() {
             write!(buf, " {}", self.args.format(buf.format()))?;
         }
