@@ -45,6 +45,7 @@ pub trait Loader: Sized + std::fmt::Debug {
 
 /// An error loading a file.
 #[non_exhaustive]
+#[derive(Debug)]
 pub enum LoadError {
     /// Reading {0} failed: {1}
     Input(String, std::io::Error),
@@ -57,20 +58,14 @@ impl std::error::Error for LoadError {}
 
 impl fmt::Display for LoadError {
     fn fmt(&self, out: &mut fmt::Formatter) -> fmt::Result {
-        write!(out, "Error: {self:?}")
-    }
-}
-
-impl fmt::Debug for LoadError {
-    fn fmt(&self, out: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            LoadError::Input(path, err) => {
+            Self::Input(path, err) => {
                 write!(out, "Reading {path:?} failed: {err}")
             }
-            LoadError::UnknownFormat(name) => {
+            Self::UnknownFormat(name) => {
                 write!(out, "{name:?} is not a css or sass file.")
             }
-            LoadError::NotCalledFromCargo => {
+            Self::NotCalledFromCargo => {
                 write!(out, "Expected a cargo environment, but none found.")
             }
         }
