@@ -1,4 +1,3 @@
-use std::iter::FromIterator;
 use std::slice::Iter;
 use std::vec::IntoIter;
 
@@ -7,18 +6,16 @@ pub struct OrderMap<K, V>(Vec<(K, V)>);
 
 impl<K: Clone + PartialEq, V: Clone> OrderMap<K, V> {
     pub fn new() -> Self {
-        OrderMap(Vec::new())
+        Self(Vec::new())
     }
     pub fn singleton(key: K, value: V) -> Self {
-        OrderMap(vec![(key, value)])
+        Self(vec![(key, value)])
     }
 
     pub fn insert(&mut self, key: K, value: V) -> Option<V> {
-        for &mut (ref k, ref mut v) in &mut self.0 {
+        for (ref k, ref mut v) in &mut self.0 {
             if k == &key {
-                let mut value = value;
-                std::mem::swap(v, &mut value);
-                return Some(value);
+                return Some(std::mem::replace(v, value));
             }
         }
         self.0.push((key, value));
@@ -76,7 +73,7 @@ impl<K: Clone + PartialEq, V: Clone> OrderMap<K, V> {
 
 impl<K, V> Default for OrderMap<K, V> {
     fn default() -> Self {
-        OrderMap(Default::default())
+        Self(Default::default())
     }
 }
 
@@ -93,6 +90,6 @@ impl<K, V> FromIterator<(K, V)> for OrderMap<K, V> {
     where
         T: IntoIterator<Item = (K, V)>,
     {
-        OrderMap(Vec::from_iter(i))
+        Self(Vec::from_iter(i))
     }
 }
