@@ -3,7 +3,7 @@ use super::cssdest::{
 };
 use super::{CssBuf, Format};
 use crate::css::{
-    Comment, CssString, Import, Item, MediaArgs, Selectors, Value,
+    Comment, CssSelectorSet, CssString, Import, Item, MediaArgs, Value,
 };
 use crate::{Error, Invalid, ScopeRef};
 use std::collections::BTreeMap;
@@ -19,7 +19,7 @@ pub struct CssData {
 
 impl CssData {
     pub fn new() -> Self {
-        CssData {
+        Self {
             imports: Default::default(),
             body: Default::default(),
             modules: Default::default(),
@@ -86,7 +86,7 @@ impl CssDestination for CssData {
         self
     }
 
-    fn start_rule(&mut self, selectors: Selectors) -> Result<RuleDest> {
+    fn start_rule(&mut self, selectors: CssSelectorSet) -> Result<RuleDest> {
         Ok(RuleDest::new(self, selectors))
     }
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest {
