@@ -1,7 +1,8 @@
 use super::CssData;
 use crate::css::{
-    AtRule, AtRuleBodyItem, Comment, CssString, CustomProperty, Import, Item,
-    MediaArgs, MediaRule, Property, Rule, Selectors, Value,
+    AtRule, AtRuleBodyItem, Comment, CssSelectorSet, CssString,
+    CustomProperty, Import, Item, MediaArgs, MediaRule, Property, Rule,
+    Value,
 };
 use crate::Invalid;
 
@@ -10,7 +11,7 @@ type Result<T = ()> = std::result::Result<T, Invalid>;
 pub trait CssDestination {
     fn head(&mut self) -> &mut CssData;
 
-    fn start_rule(&mut self, selectors: Selectors) -> Result<RuleDest>;
+    fn start_rule(&mut self, selectors: CssSelectorSet) -> Result<RuleDest>;
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest;
     fn start_atrule(&mut self, name: String, args: Value) -> AtRuleDest;
     fn start_nsrule(&mut self, name: String) -> Result<NsRuleDest>;
@@ -38,22 +39,20 @@ pub struct RuleDest<'a> {
 impl<'a> RuleDest<'a> {
     pub fn new(
         parent: &'a mut dyn CssDestination,
-        selectors: Selectors,
+        selectors: CssSelectorSet,
     ) -> Self {
         RuleDest {
             parent,
-            rule: Rule::new(selectors),
+            rule: Rule::new(selectors.into()),
             trail: Default::default(),
         }
     }
 }
-impl<'a> Drop for RuleDest<'a> {
+impl Drop for RuleDest<'_> {
     fn drop(&mut self) {
         fn end(dest: &mut RuleDest) -> Result<()> {
             dest.parent.push_item(dest.rule.clone().into())?;
-            let mut t = Vec::new();
-            std::mem::swap(&mut dest.trail, &mut t);
-            for item in t {
+            for item in std::mem::take(&mut dest.trail) {
                 dest.parent.push_item(item)?;
             }
             dest.parent.separate();
@@ -65,11 +64,11 @@ impl<'a> Drop for RuleDest<'a> {
     }
 }
 
-impl<'a> CssDestination for RuleDest<'a> {
+impl CssDestination for RuleDest<'_> {
     fn head(&mut self) -> &mut CssData {
         self.parent.head()
     }
-    fn start_rule(&mut self, selectors: Selectors) -> Result<RuleDest> {
+    fn start_rule(&mut self, selectors: CssSelectorSet) -> Result<RuleDest> {
         Ok(RuleDest::new(self, selectors))
     }
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest {
@@ -138,11 +137,11 @@ pub struct NsRuleDest<'a> {
     name: String,
 }
 
-impl<'a> CssDestination for NsRuleDest<'a> {
+impl CssDestination for NsRuleDest<'_> {
     fn head(&mut self) -> &mut CssData {
         self.parent.head()
     }
-    fn start_rule(&mut self, _selectors: Selectors) -> Result<RuleDest> {
+    fn start_rule(&mut self, _selectors: CssSelectorSet) -> Result<RuleDest> {
         Err(Invalid::InNsRule)
     }
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest {
@@ -202,16 +201,13 @@ impl<'a> AtRuleDest<'a> {
     }
 }
 
-impl<'a> Drop for AtRuleDest<'a> {
+impl Drop for AtRuleDest<'_> {
     fn drop(&mut self) {
-        let mut body = Vec::new();
-        std::mem::swap(&mut self.body, &mut body);
-        let mut name = String::new();
-        std::mem::swap(&mut self.name, &mut name);
-        let mut args = Value::Null;
-        std::mem::swap(&mut self.args, &mut args);
-        if let Some(rule) = &self.rule {
-            body.insert(0, rule.clone().into());
+        let mut body = std::mem::take(&mut self.body);
+        let name = std::mem::take(&mut self.name);
+        let args = std::mem::replace(&mut self.args, Value::Null);
+        if let Some(rule) = self.rule.take() {
+            body.insert(0, rule.into());
         }
         let result = AtRule::new(name, args, Some(body));
         if let Err(err) = self.parent.push_item(result.into()) {
@@ -220,11 +216,11 @@ impl<'a> Drop for AtRuleDest<'a> {
         self.parent.separate();
     }
 }
-impl<'a> CssDestination for AtRuleDest<'a> {
+impl CssDestination for AtRuleDest<'_> {
     fn head(&mut self) -> &mut CssData {
         self.parent.head()
     }
-    fn start_rule(&mut self, selectors: Selectors) -> Result<RuleDest> {
+    fn start_rule(&mut self, selectors: CssSelectorSet) -> Result<RuleDest> {
         Ok(RuleDest::new(self, selectors))
     }
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest {
@@ -320,15 +316,14 @@ impl<'a> AtMediaDest<'a> {
     }
 }
 
-impl<'a> Drop for AtMediaDest<'a> {
+impl Drop for AtMediaDest<'_> {
     fn drop(&mut self) {
-        let mut body = Vec::new();
-        std::mem::swap(&mut self.body, &mut body);
-        let mut args = MediaArgs::Name(String::new());
-        std::mem::swap(&mut self.args, &mut args);
-        if let Some(rule) = &self.rule {
+        let mut body = std::mem::take(&mut self.body);
+        let args =
+            std::mem::replace(&mut self.args, MediaArgs::Name(String::new()));
+        if let Some(rule) = self.rule.take() {
             if !rule.body.is_empty() {
-                body.insert(0, rule.clone().into());
+                body.insert(0, rule.into());
             }
         }
         let result = MediaRule::new(args, body);
@@ -339,12 +334,12 @@ impl<'a> Drop for AtMediaDest<'a> {
     }
 }
 
-impl<'a> CssDestination for AtMediaDest<'a> {
+impl CssDestination for AtMediaDest<'_> {
     fn head(&mut self) -> &mut CssData {
         self.parent.head()
     }
 
-    fn start_rule(&mut self, selectors: Selectors) -> Result<RuleDest> {
+    fn start_rule(&mut self, selectors: CssSelectorSet) -> Result<RuleDest> {
         Ok(RuleDest::new(self, selectors))
     }
     fn start_atmedia(&mut self, args: MediaArgs) -> AtMediaDest {
