@@ -3,11 +3,10 @@
 
 use super::cssdest::CssDestination;
 use super::CssData;
-use crate::css::{self, AtRule, Import, SelectorCtx};
+use crate::css::{self, AtRule, Import, SelectorCtx, Value};
 use crate::error::ResultPos;
 use crate::input::{Context, Loader, Parsed, SourceKind};
 use crate::sass::{get_global_module, Expose, Item, UseAs};
-use crate::value::ValueRange;
 use crate::{Error, Invalid, ScopeRef};
 
 pub fn handle_parsed(
@@ -198,16 +197,16 @@ fn handle_item(
                     }
                 }
                 let args = args.evaluate(scope.clone())?;
-                dest.push_import(Import::new(name, args));
+                dest.push_import(Import::new(Value::Literal(name), args));
             }
         }
         Item::AtRoot(ref selectors, ref body) => {
-            let selectors = selectors
-                .eval(scope.clone())?
-                .with_backref(scope.get_selectors().one());
-            let subscope = ScopeRef::sub_selectors(scope, selectors.clone());
+            let selectors = selectors.eval(scope.clone())?;
+            let ctx = scope.get_selectors().at_root(selectors);
+            let selectors = ctx.real();
+            let subscope = ScopeRef::sub_selectors(scope, ctx);
             if !selectors.is_root() {
-                let mut rule = dest.start_rule(selectors.real()).no_pos()?;
+                let mut rule = dest.start_rule(selectors).no_pos()?;
                 handle_body(body, &mut rule, subscope, file_context)?;
             } else {
                 handle_body(body, dest, subscope, file_context)?;
@@ -280,7 +279,7 @@ fn handle_item(
                         }
                         e => {
                             let pos = pos.in_call(name);
-                            Error::BadCall(format!("{e:?}"), pos, None)
+                            Error::BadCall(e.to_string(), pos, None)
                         }
                     })?;
             } else {
@@ -315,18 +314,8 @@ fn handle_item(
             }
             scope.restore_local_values(pushed);
         }
-        Item::For {
-            ref name,
-            ref from,
-            ref to,
-            inclusive,
-            ref body,
-        } => {
-            let range = ValueRange::new(
-                from.evaluate(scope.clone())?,
-                to.evaluate(scope.clone())?,
-                *inclusive,
-            )?;
+        Item::For(ref name, ref range, ref body) => {
+            let range = range.evaluate(scope.clone())?;
             check_body(body, BodyContext::Control)?;
             for value in range {
                 let scope = ScopeRef::sub(scope.clone());
@@ -358,10 +347,10 @@ fn handle_item(
 
         Item::Rule(ref selectors, ref body) => {
             check_body(body, BodyContext::Rule)?;
-            let selectors = SelectorCtx::from(selectors.eval(scope.clone())?)
-                .inside(scope.get_selectors());
-            let mut dest = dest.start_rule(selectors.real()).no_pos()?;
-            let scope = ScopeRef::sub_selectors(scope, selectors);
+            let selectors = selectors.eval(scope.clone())?;
+            let selectors = scope.get_selectors().nest(selectors);
+            let mut dest = dest.start_rule(selectors.clone()).no_pos()?;
+            let scope = ScopeRef::sub_selectors(scope, selectors.into());
             handle_body(body, &mut dest, scope, file_context)?;
         }
         Item::Property(ref name, ref value, ref pos) => {
