@@ -4,7 +4,7 @@ use super::strings::{sass_string_dq, sass_string_sq};
 use super::util::{ignore_comments, opt_spacelike, semi_or_end};
 use super::value::{
     self, any_additive_expr, any_product, bracket_list, dictionary,
-    function_call_or_string, variable,
+    function_call_or_string_rulearg, variable,
 };
 use super::{body_block, list_or_single, PResult};
 use crate::sass::{BinOp, Item, Value};
@@ -13,18 +13,20 @@ use nom::branch::alt;
 use nom::bytes::complete::tag;
 use nom::combinator::{into, map, opt, value};
 use nom::multi::{many0, separated_list0};
-use nom::sequence::{delimited, preceded, terminated, tuple};
+use nom::sequence::{delimited, preceded, terminated};
+use nom::Parser as _;
 
 #[cfg(test)]
 use super::check_parse;
 
 pub fn rule<'a>(start: Span, input: Span<'a>) -> PResult<'a, Item> {
     let pos = start.up_to(&input).to_owned();
-    let (input, args) = opt(terminated(args, opt_spacelike))(input)?;
+    let (input, args) = opt(terminated(args, opt_spacelike)).parse(input)?;
     let (input, body) = preceded(
         opt_spacelike,
         alt((map(body_block, Some), value(None, semi_or_end))),
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((
         input,
         Item::AtMedia {
@@ -53,7 +55,7 @@ pub fn args(input: Span) -> PResult<Value> {
                     bracket_list,
                     into(value::numeric),
                     variable,
-                    map(function_call_or_string, |s| match s {
+                    map(function_call_or_string_rulearg, |s| match s {
                         Value::Literal(s) => Value::Literal({
                             let lower = s
                                 .single_raw()
@@ -73,16 +75,18 @@ pub fn args(input: Span) -> PResult<Value> {
             )),
             |args| list_or_single(args, ListSeparator::Space),
         ),
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, list_or_single(args, ListSeparator::Comma)))
 }
 
 fn media_relation(input: Span) -> PResult<Value> {
     let (rest, first) = media_additive_expr(input)?;
-    if let Ok((rest, (op, b))) = tuple((
+    if let Ok((rest, (op, b))) = (
         delimited(opt_spacelike, relational_operator, opt_spacelike),
         media_relation,
-    ))(rest)
+    )
+        .parse(rest)
     {
         let pos = input.up_to(&rest).to_owned();
         Ok((
