@@ -26,11 +26,16 @@ use self::util::{
     spacelike,
 };
 use self::value::{
-    dictionary, function_call_or_string, single_value, value_expression,
+    dictionary, function_call_or_string_rulearg, single_value,
+    value_expression,
 };
 use crate::input::{SourceFile, SourceName, SourcePos};
-use crate::sass::parser::{variable_declaration2, variable_declaration_mod};
-use crate::sass::{Callable, FormalArgs, Item, Name, Selectors, Value};
+use crate::sass::parser::{
+    src_range, variable_declaration2, variable_declaration_mod,
+};
+use crate::sass::{
+    Callable, FormalArgs, Item, Name, Selectors, SrcValue, Value,
+};
 use crate::value::ListSeparator;
 #[cfg(test)]
 use crate::value::{Numeric, Unit};
@@ -38,17 +43,19 @@ use crate::Error;
 use imports::{forward2, import2, use2};
 use nom::branch::alt;
 use nom::bytes::complete::{is_a, is_not, tag};
-use nom::character::complete::one_of;
+use nom::character::complete::{char, one_of};
 use nom::combinator::{
-    all_consuming, into, map, map_res, opt, peek, value, verify,
+    all_consuming, into, map, map_res, not, opt, peek, value, verify,
 };
+use nom::error::context;
 use nom::multi::{many0, many_till, separated_list0, separated_list1};
 use nom::sequence::{delimited, pair, preceded, terminated};
-use nom::IResult;
+use nom::{IResult, Parser as _};
+use nom_language::error::VerboseError;
 use std::str::{from_utf8, Utf8Error};
 
 /// A Parsing Result; ok gives a span for the rest of the data and a parsed T.
-pub(crate) type PResult<'a, T> = IResult<Span<'a>, T>;
+pub(crate) type PResult<'a, T> = IResult<Span<'a>, T, VerboseError<Span<'a>>>;
 
 pub(crate) fn code_span(value: &[u8]) -> SourcePos {
     SourceFile::scss_bytes(value, SourceName::root("(rsass)")).into()
@@ -63,7 +70,7 @@ pub(crate) fn input_span(value: impl Into<Vec<u8>>) -> SourcePos {
 /// Returns a single value (or an error).
 pub fn parse_value_data(data: &[u8]) -> Result<Value, Error> {
     let data = code_span(data);
-    let value = all_consuming(value_expression)(data.borrow());
+    let value = all_consuming(value_expression).parse(data.borrow());
     Ok(ParseError::check(value)?)
 }
 
@@ -91,46 +98,49 @@ pub(crate) fn sassfile(input: Span) -> PResult<Vec<Item>> {
             ),
             |(v, _eof)| v,
         ),
-    )(input)
+    )
+    .parse(input)
 }
 
 fn top_level_item(input: Span) -> PResult<Item> {
-    let (rest, tag) = alt((tag("$"), tag("/*"), tag("@"), tag("")))(input)?;
+    let (rest, tag) =
+        alt((tag("$"), tag("/*"), tag("@"), tag(""))).parse(input)?;
     match tag.fragment() {
-        b"$" => into(variable_declaration2)(rest),
+        b"$" => into(variable_declaration2).parse(rest),
         b"/*" => comment_item(rest),
         b"@" => at_rule2(input),
-        b"" => alt((into(variable_declaration_mod), rule))(input),
+        b"" => alt((into(variable_declaration_mod), rule)).parse(input),
         _ => unreachable!(),
     }
 }
 
 fn comment_item(input: Span) -> PResult<Item> {
-    map(comment2, Item::Comment)(input)
+    map(comment2, Item::Comment).parse(input)
 }
 
 fn rule(input: Span) -> PResult<Item> {
     map(pair(rule_start, body_block2), |(selectors, body)| {
         Item::Rule(selectors, body)
-    })(input)
+    })
+    .parse(input)
 }
 
 fn rule_start(input: Span) -> PResult<Selectors> {
-    terminated(selectors, terminated(opt(is_a(", \t\r\n")), tag("{")))(input)
+    terminated(selectors, terminated(opt(is_a(", \t\r\n")), tag("{")))
+        .parse(input)
 }
 
 fn body_item(input: Span) -> PResult<Item> {
     let (rest, tag) =
-        alt((tag("$"), tag("/*"), tag(";"), tag("@"), tag("--"), tag("")))(
-            input,
-        )?;
+        alt((tag("$"), tag("/*"), tag(";"), tag("@"), tag("--"), tag("")))
+            .parse(input)?;
     match tag.fragment() {
-        b"$" => into(variable_declaration2)(rest),
+        b"$" => into(variable_declaration2).parse(rest),
         b"/*" => comment_item(rest),
         b";" => Ok((rest, Item::None)),
         b"@" => at_rule2(input),
         b"--" => {
-            let result = custom_property(rest);
+            let result = custom_property(input);
             if result.is_err() {
                 // Note use of `input` rather than `rest` here.
                 if let Ok((rest, rule)) = rule(input) {
@@ -161,21 +171,25 @@ fn at_root2(input: Span) -> PResult<Item> {
             ),
             |(selectors, body)| Item::AtRoot(selectors, body),
         ),
-    )(input)
+    )
+    .parse(input)
 }
 
 /// What follows the `@include` tag.
 fn mixin_call<'a>(start: Span, input: Span<'a>) -> PResult<'a, Item> {
-    let (rest, n1) = terminated(name, opt_spacelike)(input)?;
-    let (rest, n2) = opt(preceded(tag("."), name))(rest)?;
+    let (rest, n1) = terminated(name, opt_spacelike).parse(input)?;
+    let (rest, n2) = opt(preceded(tag("."), name)).parse(rest)?;
     let name = n2.map(|n2| format!("{n1}.{n2}")).unwrap_or(n1);
     let (rest, _) = opt_spacelike(rest)?;
-    let (rest0, args) = terminated(opt(call_args), opt_spacelike)(rest)?;
-    let (rest, t) = alt((tag("using"), tag("{"), tag("")))(rest0)?;
+    let (rest0, args) =
+        terminated(opt(call_args), ignore_comments).parse(rest)?;
+    let (rest, t) = alt((tag("using"), tag("{"), tag(""))).parse(rest0)?;
     let (end, body) = match t.fragment() {
         b"using" => {
-            let (end, args) = preceded(opt_spacelike, formal_args)(rest)?;
-            let (rest, body) = preceded(opt_spacelike, body_block)(end)?;
+            let (end, args) =
+                preceded(ignore_comments, formal_args).parse(rest)?;
+            let (rest, body) =
+                preceded(ignore_comments, body_block).parse(end)?;
             let decl = rest0.up_to(&end).to_owned();
             (rest, Some(Callable::new(args, body, decl)))
         }
@@ -184,10 +198,7 @@ fn mixin_call<'a>(start: Span, input: Span<'a>) -> PResult<'a, Item> {
             let decl = rest0.up_to(&rest).to_owned();
             (rest, Some(Callable::no_args(body, decl)))
         }
-        _ => {
-            let (rest, _) = opt(tag(";"))(rest)?;
-            (rest, None)
-        }
+        _ => map(semi_or_end, |_| None).parse(rest)?,
     };
     let pos = start.up_to(&rest).to_owned();
     Ok((
@@ -198,28 +209,29 @@ fn mixin_call<'a>(start: Span, input: Span<'a>) -> PResult<'a, Item> {
 
 /// When we know that `input0` starts with an `@` sign.
 fn at_rule2(input0: Span) -> PResult<Item> {
-    let (input, name) =
-        delimited(tag("@"), sass_string, opt_spacelike)(input0)?;
+    let (input, name) = delimited(
+        tag("@"),
+        context("Expected identifier.", sass_string),
+        ignore_comments,
+    )
+    .parse(input0)?;
     match name.single_raw().unwrap_or("") {
         "at-root" => at_root2(input),
         "charset" => charset2(input),
         "content" => content_stmt2(input),
-        "debug" => map(expression_argument, Item::Debug)(input),
+        "debug" => map(expression_argument, Item::Debug).parse(input),
         "each" => each_loop2(input),
         "error" => {
             let (end, v) = value_expression(input)?;
-            let (rest, _) = opt(tag(";"))(end)?;
+            let (rest, _) = opt(tag(";")).parse(end)?;
             let pos = input0.up_to(&end).to_owned();
             Ok((rest, Item::Error(v, pos)))
         }
         "extend" => map(
-            delimited(
-                opt_spacelike,
-                selectors,
-                preceded(opt_spacelike, tag(";")),
-            ),
+            delimited(opt_spacelike, selectors, semi_or_end),
             Item::Extend,
-        )(input),
+        )
+        .parse(input),
         "for" => for_loop2(input),
         "forward" => forward2(input0, input),
         "function" => function_declaration2(input),
@@ -230,7 +242,7 @@ fn at_rule2(input0: Span) -> PResult<Item> {
         "mixin" => mixin_declaration2(input),
         "return" => return_stmt2(input0, input),
         "use" => use2(input0, input),
-        "warn" => map(expression_argument, Item::Warn)(input),
+        "warn" => map(expression_argument, Item::Warn).parse(input),
         "while" => while_loop2(input),
         _ => unknown_atrule(name, input0, input),
     }
@@ -241,7 +253,7 @@ fn unknown_atrule<'a>(
     input: Span<'a>,
 ) -> PResult<'a, Item> {
     let (input, args) =
-        terminated(opt(unknown_rule_args), opt(ignore_space))(input)?;
+        terminated(opt(unknown_rule_args), opt(ignore_space)).parse(input)?;
     fn x_args(value: Value) -> Value {
         match value {
             Value::Variable(name, _pos) => {
@@ -256,9 +268,9 @@ fn unknown_atrule<'a>(
         }
     }
     let (rest, body) = if input.first() == Some(&b'{') {
-        map(body_block, Some)(input)?
+        map(body_block, Some).parse(input)?
     } else {
-        value(None, semi_or_end)(input)?
+        value(None, semi_or_end).parse(input)?
     };
     Ok((
         rest,
@@ -272,7 +284,7 @@ fn unknown_atrule<'a>(
 }
 
 fn expression_argument(input: Span) -> PResult<Value> {
-    terminated(value_expression, opt(tag(";")))(input)
+    terminated(value_expression, opt(tag(";"))).parse(input)
 }
 
 fn charset2(input: Span) -> PResult<Item> {
@@ -291,7 +303,8 @@ fn charset2(input: Span) -> PResult<Item> {
                 }
             })
         },
-    )(input)
+    )
+    .parse(input)
 }
 
 /// Arguments to an unkown at rule.
@@ -300,11 +313,11 @@ fn unknown_rule_args(input: Span) -> PResult<Value> {
         preceded(tag(","), opt_spacelike),
         map(
             many0(preceded(
-                opt(ignore_space),
+                opt_spacelike,
                 alt((
                     terminated(
                         alt((
-                            function_call_or_string,
+                            function_call_or_string_rulearg,
                             dictionary,
                             map(
                                 delimited(tag("("), media::args, tag(")")),
@@ -313,10 +326,13 @@ fn unknown_rule_args(input: Span) -> PResult<Value> {
                             map(sass_string_dq, Value::Literal),
                             map(sass_string_sq, Value::Literal),
                         )),
-                        alt((
-                            value((), all_consuming(tag(""))),
-                            value((), peek(one_of(") \r\n\t{,;"))),
-                        )),
+                        terminated(
+                            alt((
+                                value((), all_consuming(tag(""))),
+                                value((), peek(one_of(") \r\n\t{,;/"))),
+                            )),
+                            opt_spacelike,
+                        ),
                     ),
                     map(map_res(is_not("\"'{};#"), input_to_str), |s| {
                         Value::Literal(s.trim_end().into())
@@ -325,7 +341,8 @@ fn unknown_rule_args(input: Span) -> PResult<Value> {
             )),
             |args| list_or_single(args, ListSeparator::Space),
         ),
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, list_or_single(args, ListSeparator::Comma)))
 }
 
@@ -341,23 +358,25 @@ fn if_statement_inner(input: Span) -> PResult<Item> {
     preceded(
         terminated(verify(name, |n: &String| n == "if"), opt_spacelike),
         if_statement2,
-    )(input)
+    )
+    .parse(input)
 }
 
 fn if_statement2(input: Span) -> PResult<Item> {
-    let (input, cond) = terminated(value_expression, opt_spacelike)(input)?;
+    let (input, cond) =
+        terminated(value_expression, opt_spacelike).parse(input)?;
     let (input, body) = body_block(input)?;
     let (input2, word) = opt(delimited(
         preceded(opt_spacelike, tag("@")),
         name,
         opt_spacelike,
-    ))(input)?;
+    ))
+    .parse(input)?;
     match word.as_ref().map(AsRef::as_ref) {
         Some("else") => {
-            let (input2, else_body) = alt((
-                body_block,
-                map(if_statement_inner, |s| vec![s]),
-            ))(input2)?;
+            let (input2, else_body) =
+                alt((map(if_statement_inner, |s| vec![s]), body_block))
+                    .parse(input2)?;
             Ok((input2, Item::IfStatement(cond, body, else_body)))
         }
         Some("elseif") => {
@@ -373,52 +392,50 @@ fn each_loop2(input: Span) -> PResult<Item> {
     let (input, names) = separated_list1(
         delimited(opt_spacelike, tag(","), opt_spacelike),
         map(preceded(tag("$"), name), Name::from),
-    )(input)?;
+    )
+    .parse(input)?;
     let (input, values) = delimited(
         delimited(spacelike, tag("in"), spacelike),
         value_expression,
         opt_spacelike,
-    )(input)?;
+    )
+    .parse(input)?;
     let (input, body) = body_block(input)?;
     Ok((input, Item::Each(names, values, body)))
 }
 
 /// A for loop after the initial `@for`.
 fn for_loop2(input: Span) -> PResult<Item> {
-    let (input, name) = delimited(tag("$"), name, spacelike)(input)?;
-    let (input, from) = delimited(
-        terminated(tag("from"), spacelike),
-        single_value,
-        spacelike,
-    )(input)?;
-    let (input, inclusive) = terminated(
-        alt((value(true, tag("through")), value(false, tag("to")))),
-        spacelike,
-    )(input)?;
-    let (input, to) = terminated(single_value, opt_spacelike)(input)?;
+    let (input, name) =
+        delimited(tag("$"), name, ignore_comments).parse(input)?;
+    let (input, range) = src_range(input)?;
     let (input, body) = body_block(input)?;
-    Ok((
-        input,
-        Item::For {
-            name: name.into(),
-            from: Box::new(from),
-            to: Box::new(to),
-            inclusive,
-            body,
-        },
-    ))
+    Ok((input, Item::For(name.into(), range, body)))
+}
+
+/// A single `SrcValue`.
+///
+/// That is, a single sass value with source position.
+pub fn single_value_p(input: Span) -> PResult<SrcValue> {
+    let (rest, value) = single_value(input)?;
+    let pos = input.up_to(&rest).to_owned();
+    Ok((rest, SrcValue::new(value, pos)))
 }
 
 fn while_loop2(input: Span) -> PResult<Item> {
-    let (input, cond) = terminated(value_expression, opt_spacelike)(input)?;
+    let (input, cond) =
+        terminated(value_expression, opt_spacelike).parse(input)?;
     let (input, body) = body_block(input)?;
     Ok((input, Item::While(cond, body)))
 }
 
 fn mixin_declaration2(input: Span) -> PResult<Item> {
-    let (rest, name) = terminated(name, opt_spacelike)(input)?;
-    let (rest, args) = opt(formal_args)(rest)?;
-    let (end, body) = preceded(opt_spacelike, body_block)(rest)?;
+    let (rest, (name, args)) = pair(
+        terminated(name, ignore_comments),
+        alt((value(None, peek(not(char('(')))), map(formal_args, Some))),
+    )
+    .parse(input)?;
+    let (end, body) = preceded(ignore_comments, body_block).parse(rest)?;
     let args = args.unwrap_or_else(FormalArgs::none);
     let decl = input.up_to(&rest).to_owned();
     Ok((
@@ -428,9 +445,9 @@ fn mixin_declaration2(input: Span) -> PResult<Item> {
 }
 
 fn function_declaration2(input: Span) -> PResult<Item> {
-    let (end, name) = terminated(name, opt_spacelike)(input)?;
+    let (end, name) = terminated(name, ignore_comments).parse(input)?;
     let (end, args) = formal_args(end)?;
-    let (rest, body) = preceded(opt_spacelike, body_block)(end)?;
+    let (rest, body) = preceded(ignore_comments, body_block).parse(end)?;
     let decl = input.up_to(&end).to_owned();
     Ok((
         rest,
@@ -440,28 +457,22 @@ fn function_declaration2(input: Span) -> PResult<Item> {
 
 fn return_stmt2<'a>(start: Span, input: Span<'a>) -> PResult<'a, Item> {
     let (input, v) =
-        delimited(opt_spacelike, value_expression, opt_spacelike)(input)?;
+        terminated(value_expression, ignore_comments).parse(input)?;
     let pos = start.up_to(&input).to_owned();
-    let (input, _) = opt(tag(";"))(input)?;
+    let (input, _) = opt(tag(";")).parse(input)?;
     Ok((input, Item::Return(v, pos)))
 }
 
-/// The "rest" of an `@content` statement is just an optional terminator
 fn content_stmt2(input: Span) -> PResult<Item> {
-    let (rest, _) = opt_spacelike(input)?;
-    let (rest, args) = opt(call_args)(rest)?;
-    let (rest, _) = opt(tag(";"))(rest)?;
+    let (rest, args) =
+        terminated(opt(call_args), opt(tag(";"))).parse(input)?;
     let pos = input.up_to(&rest).to_owned();
     Ok((rest, Item::Content(args.unwrap_or_default(), pos)))
 }
 
 fn custom_property(input: Span) -> PResult<Item> {
-    let (rest, name) = terminated(opt(sass_string), tag(":"))(input)?;
-    let mut name = name.unwrap_or_else(|| SassString::from(""));
-    // The dashes was parsed before calling this method.
-    name.prepend("--");
-    let (rest, value) =
-        terminated(custom_value, alt((tag(";"), peek(tag("}")))))(rest)?;
+    let (rest, name) = terminated(sass_string, char(':')).parse(input)?;
+    let (rest, value) = terminated(custom_value, semi_or_end).parse(rest)?;
     Ok((rest, Item::CustomProperty(name, value)))
 }
 
@@ -474,26 +485,24 @@ fn property_or_namespace_rule(input: Span) -> PResult<Item> {
             }),
             sass_string,
         )),
-        delimited(ignore_comments, tag(":"), ignore_comments),
-    )(input)?;
+        delimited(ignore_comments, char(':'), ignore_comments),
+    )
+    .parse(input)?;
 
-    let (input, val) = opt(value_expression)(start_val)?;
-    let pos = start_val.up_to(&input).to_owned();
-    let (input, _) = opt_spacelike(input)?;
+    let (input, val) = alt((
+        map(peek(char('{')), |_| None),
+        map(context("Expected expression.", value_expression), Some),
+    ))
+    .parse(start_val)?;
 
-    let (input, next) = if val.is_some() {
-        alt((tag("{"), tag(";"), tag("")))(input)?
-    } else {
-        tag("{")(input)?
-    };
+    let pos = start_val.up_to(&input);
 
-    let (input, body) = if next.fragment() == b"{" {
-        map(body_block2, Some)(input)?
-    } else {
-        (input, None)
-    };
-    let (input, _) = opt_spacelike(input)?;
-    Ok((input, ns_or_prop_item(name, val, body, pos)))
+    let (input, body) = preceded(
+        ignore_comments,
+        alt((map(semi_or_end, |_| None), map(body_block, Some))),
+    )
+    .parse(input)?;
+    Ok((input, ns_or_prop_item(name, val, body, pos.to_owned())))
 }
 
 use crate::sass::SassString;
@@ -513,7 +522,7 @@ fn ns_or_prop_item(
 }
 
 fn body_block(input: Span) -> PResult<Vec<Item>> {
-    preceded(tag("{"), body_block2)(input)
+    preceded(char('{'), body_block2).parse(input)
 }
 
 fn body_block2(input: Span) -> PResult<Vec<Item>> {
@@ -523,11 +532,12 @@ fn body_block2(input: Span) -> PResult<Vec<Item>> {
             terminated(body_item, opt_spacelike),
             terminated(terminated(tag("}"), opt_spacelike), opt(tag(";"))),
         ),
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, v))
 }
 
-fn input_to_str(s: Span) -> Result<&str, Utf8Error> {
+pub(crate) fn input_to_str(s: Span) -> Result<&str, Utf8Error> {
     from_utf8(s.fragment())
 }
 
