@@ -1,24 +1,34 @@
-use super::strings::{sass_string, sass_string_dq, sass_string_sq};
+use super::strings::{
+    sass_string, sass_string_allow_dash, sass_string_dq, sass_string_sq,
+};
 use super::util::{ignore_comments, opt_spacelike, spacelike2};
 use super::{input_to_string, PResult, Span};
 use crate::sass::{Selector, SelectorPart, Selectors};
 use nom::branch::alt;
 use nom::bytes::complete::tag;
 use nom::character::complete::one_of;
-use nom::combinator::{map, map_res, opt, value};
+use nom::combinator::{map, map_opt, map_res, opt, value};
 use nom::multi::{many1, separated_list1};
-use nom::sequence::{delimited, pair, preceded, terminated, tuple};
+use nom::sequence::{delimited, pair, preceded, terminated};
+use nom::Parser as _;
 
 pub fn selectors(input: Span) -> PResult<Selectors> {
-    let (input, v) = separated_list1(
-        terminated(tag(","), ignore_comments),
-        opt(selector),
-    )(input)?;
-    Ok((input, Selectors::new(v.into_iter().flatten().collect())))
+    map_opt(
+        separated_list1(terminated(tag(","), ignore_comments), opt(selector)),
+        |v| {
+            let v = v.into_iter().flatten().collect::<Vec<_>>();
+            if v.is_empty() {
+                None
+            } else {
+                Some(Selectors::new(v))
+            }
+        },
+    )
+    .parse(input)
 }
 
 pub fn selector(input: Span) -> PResult<Selector> {
-    let (input, mut s) = many1(selector_part)(input)?;
+    let (input, mut s) = many1(selector_part).parse(input)?;
     if s.last() == Some(&SelectorPart::Descendant) {
         s.pop();
     }
@@ -28,7 +38,9 @@ pub fn selector(input: Span) -> PResult<Selector> {
 fn selector_part(input: Span) -> PResult<SelectorPart> {
     alt((
         map(
-            tuple((opt(tag("%")), sass_string, opt(tag("%")))),
+            // A single dash is allowed as a selector, because the parsing
+            // of psedudo-element attributes don't handle expressions yet.
+            (opt(tag("%")), sass_string_allow_dash, opt(tag("%"))),
             |(pre, mut s, post)| {
                 if pre.is_some() {
                     s.prepend("%");
@@ -63,7 +75,7 @@ fn selector_part(input: Span) -> PResult<SelectorPart> {
         map(
             delimited(
                 terminated(tag("["), opt_spacelike),
-                tuple((
+                (
                     terminated(sass_string, opt_spacelike),
                     terminated(
                         map_res(
@@ -90,7 +102,7 @@ fn selector_part(input: Span) -> PResult<SelectorPart> {
                         ),
                         opt_spacelike,
                     )),
-                )),
+                ),
                 tag("]"),
             ),
             |(name, op, val, modifier)| SelectorPart::Attribute {
@@ -125,7 +137,8 @@ fn selector_part(input: Span) -> PResult<SelectorPart> {
             opt_spacelike,
         ),
         value(SelectorPart::Descendant, spacelike2),
-    ))(input)
+    ))
+    .parse(input)
 }
 
 #[cfg(test)]
