@@ -1,10 +1,7 @@
 use crate::input::{SourceFile, SourcePos};
-use nom::{
-    Compare, CompareResult, InputIter, InputLength, InputTake,
-    InputTakeAtPosition, Needed, Offset, Slice,
-};
+use nom::{Compare, CompareResult, Input, Needed, Offset};
 use std::fmt::Write;
-use std::ops::{Deref, Range, RangeFrom, RangeTo};
+use std::ops::{Deref, Range};
 
 /// A specific piece of input data.
 #[derive(Clone, Copy)]
@@ -34,6 +31,9 @@ impl<'a> Span<'a> {
             source,
         }
     }
+    pub(crate) fn is_at_end(&self) -> bool {
+        self.start == self.source.data().len()
+    }
     fn range(&self) -> Range<usize> {
         self.start..self.end
     }
@@ -66,6 +66,15 @@ impl<'a> Span<'a> {
     pub(crate) fn up_to(self, other: &Self) -> Self {
         self.take(self.offset(other))
     }
+    /// If `self` goes on the end of input, return just the starting point.
+    /// Otherwise preserve `self` as is.
+    pub(crate) fn sanitize_end(self) -> Self {
+        if self.end < self.source.data().len() {
+            self
+        } else {
+            self.up_to(&self)
+        }
+    }
 }
 
 impl<'a, T> Compare<T> for Span<'a>
@@ -80,38 +89,40 @@ where
     }
 }
 
-impl<'a> InputLength for Span<'a> {
+impl<'a> Input for Span<'a> {
+    type Item = u8;
+
+    type Iter = <&'a [u8] as Input>::Iter;
+
+    type IterIndices = <&'a [u8] as Input>::IterIndices;
+
     fn input_len(&self) -> usize {
-        self.range().len()
+        self.end - self.start
     }
-}
 
-impl<'a> Deref for Span<'a> {
-    type Target = [u8];
-    fn deref(&self) -> &'a [u8] {
-        self.fragment()
-    }
-}
-
-impl<'a> AsRef<[u8]> for Span<'a> {
-    fn as_ref(&self) -> &[u8] {
-        self.fragment()
-    }
-}
-
-impl<'a> InputTake for Span<'a> {
-    fn take(&self, count: usize) -> Self {
-        let end = self.start + count;
-        assert!(end <= self.end, "Tried to take {count} from {self:?}");
+    fn take(&self, index: usize) -> Self {
+        let end = self.start + index;
+        assert!(end <= self.end, "Tried to take {index} from {self:?}");
         Span {
             start: self.start,
             end,
             source: self.source,
         }
     }
-    fn take_split(&self, count: usize) -> (Self, Self) {
-        let mid = self.start + count;
-        assert!(mid <= self.end, "Tried to take_split {count} from {self:?}");
+
+    fn take_from(&self, index: usize) -> Self {
+        let mid = self.start + index;
+        assert!(mid <= self.end, "Tried to take_from {index} from {self:?}");
+        Span {
+            start: mid,
+            end: self.end,
+            source: self.source,
+        }
+    }
+
+    fn take_split(&self, index: usize) -> (Self, Self) {
+        let mid = self.start + index;
+        assert!(mid <= self.end, "Tried to take_split {index} from {self:?}");
         (
             Span {
                 start: mid,
@@ -125,66 +136,35 @@ impl<'a> InputTake for Span<'a> {
             },
         )
     }
-}
 
-impl<'a> Slice<Range<usize>> for Span<'a> {
-    fn slice(&self, range: Range<usize>) -> Self {
-        let start = self.start + range.start;
-        let end = self.start + range.end;
-        assert!(start <= self.end);
-        assert!(end <= self.end);
-        Span {
-            start,
-            end,
-            source: self.source,
-        }
-    }
-}
-impl<'a> Slice<RangeFrom<usize>> for Span<'a> {
-    fn slice(&self, range: RangeFrom<usize>) -> Self {
-        let start = self.start + range.start;
-        assert!(start <= self.end);
-        Span {
-            start,
-            end: self.end,
-            source: self.source,
-        }
-    }
-}
-impl<'a> Slice<RangeTo<usize>> for Span<'a> {
-    fn slice(&self, range: RangeTo<usize>) -> Self {
-        let end = self.start + range.end;
-        assert!(end <= self.end);
-        Span {
-            start: self.start,
-            end,
-            source: self.source,
-        }
-    }
-}
-
-impl<'a> InputIter for Span<'a> {
-    type Item = <&'a [u8] as InputIter>::Item;
-    type Iter = <&'a [u8] as InputIter>::Iter;
-    type IterElem = <&'a [u8] as InputIter>::IterElem;
-    fn iter_indices(&self) -> Self::Iter {
-        self.fragment().iter_indices()
-    }
-    fn iter_elements(&self) -> Self::IterElem {
-        self.fragment().iter_elements()
-    }
     fn position<P>(&self, predicate: P) -> Option<usize>
     where
         P: Fn(Self::Item) -> bool,
     {
         self.fragment().position(predicate)
     }
+
+    fn iter_elements(&self) -> Self::Iter {
+        self.fragment().iter_elements()
+    }
+
+    fn iter_indices(&self) -> Self::IterIndices {
+        self.fragment().iter_indices()
+    }
+
     fn slice_index(&self, count: usize) -> Result<usize, Needed> {
         self.fragment().slice_index(count)
     }
 }
 
-impl<'a> Offset for Span<'a> {
+impl<'a> Deref for Span<'a> {
+    type Target = [u8];
+    fn deref(&self) -> &'a [u8] {
+        self.fragment()
+    }
+}
+
+impl Offset for Span<'_> {
     fn offset(&self, second: &Self) -> usize {
         assert!(std::ptr::eq(self.source, second.source));
         second.start - self.start
@@ -196,74 +176,7 @@ pub fn position(s: Span) -> super::PResult<Span> {
     Ok((s, s))
 }
 
-impl<'a> InputTakeAtPosition for Span<'a> {
-    type Item = u8;
-
-    fn split_at_position<P, E: nom::error::ParseError<Self>>(
-        &self,
-        predicate: P,
-    ) -> nom::IResult<Self, Self, E>
-    where
-        P: Fn(Self::Item) -> bool,
-    {
-        match self.position(predicate) {
-            Some(n) => Ok(self.take_split(n)),
-            None => Err(nom::Err::Incomplete(Needed::new(1))),
-        }
-    }
-
-    fn split_at_position1<P, E: nom::error::ParseError<Self>>(
-        &self,
-        predicate: P,
-        e: nom::error::ErrorKind,
-    ) -> nom::IResult<Self, Self, E>
-    where
-        P: Fn(Self::Item) -> bool,
-    {
-        match self.position(predicate) {
-            Some(0) => Err(nom::Err::Error(E::from_error_kind(*self, e))),
-            Some(n) => Ok(self.take_split(n)),
-            None => Err(nom::Err::Incomplete(Needed::new(1))),
-        }
-    }
-
-    fn split_at_position_complete<P, E: nom::error::ParseError<Self>>(
-        &self,
-        predicate: P,
-    ) -> nom::IResult<Self, Self, E>
-    where
-        P: Fn(Self::Item) -> bool,
-    {
-        match self.split_at_position(predicate) {
-            Err(nom::Err::Incomplete(_)) => {
-                Ok(self.take_split(self.input_len()))
-            }
-            res => res,
-        }
-    }
-
-    fn split_at_position1_complete<P, E: nom::error::ParseError<Self>>(
-        &self,
-        predicate: P,
-        e: nom::error::ErrorKind,
-    ) -> nom::IResult<Self, Self, E>
-    where
-        P: Fn(Self::Item) -> bool,
-    {
-        match self.split_at_position1(predicate, e) {
-            Err(nom::Err::Incomplete(_)) => {
-                if self.input_len() == 0 {
-                    Err(nom::Err::Error(E::from_error_kind(*self, e)))
-                } else {
-                    Ok(self.take_split(self.input_len()))
-                }
-            }
-            res => res,
-        }
-    }
-}
-
-impl<'a> std::fmt::Debug for Span<'a> {
+impl std::fmt::Debug for Span<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Span")
             .field("range", &self.range())
@@ -274,7 +187,7 @@ impl<'a> std::fmt::Debug for Span<'a> {
 
 pub(crate) struct DebugBytes<'a>(pub(crate) &'a [u8]);
 
-impl<'a> std::fmt::Debug for DebugBytes<'a> {
+impl std::fmt::Debug for DebugBytes<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.write_char('"')?;
         for b in self.0 {
