@@ -4,19 +4,27 @@ use crate::sass::{SassString, StringPart};
 use crate::value::Quotes;
 use nom::branch::alt;
 use nom::bytes::complete::{is_a, is_not, tag, take};
-use nom::character::complete::{alphanumeric1, one_of};
+use nom::character::complete::{alphanumeric1, char, one_of};
 use nom::combinator::{
-    map, map_opt, map_res, not, opt, peek, recognize, value, verify,
+    cut, map, map_opt, map_res, not, opt, peek, recognize, value, verify,
 };
+use nom::error::context;
 use nom::multi::{fold_many0, fold_many1, many0, many1, many_m_n};
-use nom::sequence::{delimited, pair, preceded, terminated, tuple};
+use nom::sequence::{delimited, pair, preceded, terminated};
+use nom::Parser as _;
 use std::str::from_utf8;
 
 pub fn sass_string(input: Span) -> PResult<SassString> {
+    verify(sass_string_allow_dash, |s| s.single_raw() != Some("-"))
+        .parse(input)
+}
+
+pub fn sass_string_allow_dash(input: Span) -> PResult<SassString> {
     let (input, first) = alt((
         string_part_interpolation,
         map(unquoted_first_part, StringPart::Raw),
-    ))(input)?;
+    ))
+    .parse(input)?;
     let (input, parts) = fold_many0(
         alt((
             string_part_interpolation,
@@ -27,42 +35,32 @@ pub fn sass_string(input: Span) -> PResult<SassString> {
             acc.push(item);
             acc
         },
-    )(input)?;
-    Ok((input, SassString::new(parts, Quotes::None)))
-}
-pub fn var_name(input: Span) -> PResult<SassString> {
-    let (input, _) = tag("--")(input)?;
-    let (input, parts) = fold_many0(
-        alt((
-            string_part_interpolation,
-            map(unquoted_part, StringPart::Raw),
-        )),
-        || vec![StringPart::Raw("--".into())],
-        |mut acc, item| {
-            acc.push(item);
-            acc
-        },
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, SassString::new(parts, Quotes::None)))
 }
 
 pub fn custom_value(input: Span) -> PResult<SassString> {
-    map(custom_value_inner, |mut parts| {
-        if let Some(StringPart::Raw(last)) = parts.last_mut() {
-            if last.ends_with('\n') {
-                last.pop();
-                last.push(' ');
+    map(
+        context("Expected token.", custom_value_inner),
+        |mut parts| {
+            if let Some(StringPart::Raw(last)) = parts.last_mut() {
+                if last.ends_with('\n') {
+                    last.pop();
+                    last.push(' ');
+                }
             }
-        }
-        SassString::new(parts, Quotes::None)
-    })(input)
+            SassString::new(parts, Quotes::None)
+        },
+    )
+    .parse(input)
 }
 pub fn custom_value_inner(input: Span) -> PResult<Vec<StringPart>> {
     fold_many1(
         alt((
-            |input| custom_value_paren("[", "]", input),
-            |input| custom_value_paren("{", "}", input),
-            |input| custom_value_paren("(", ")", input),
+            |input| custom_value_paren('[', ']', input),
+            |input| custom_value_paren('{', '}', input),
+            |input| custom_value_paren('(', ')', input),
             map(sass_string_dq, |mut s| {
                 s.prepend("\"");
                 s.append_str("\"");
@@ -88,17 +86,18 @@ pub fn custom_value_inner(input: Span) -> PResult<Vec<StringPart>> {
             acc.extend(items);
             acc
         },
-    )(input)
+    )
+    .parse(input)
 }
 
-fn custom_value_paren<'a>(
-    start: &'static str,
-    end: &'static str,
-    input: Span<'a>,
-) -> PResult<'a, Vec<StringPart>> {
+fn custom_value_paren(
+    start: char,
+    end: char,
+    input: Span,
+) -> PResult<Vec<StringPart>> {
     map(
         delimited(
-            tag(start),
+            char(start),
             fold_many0(
                 alt((
                     map(tag(";"), |_| vec![StringPart::from(";")]),
@@ -110,32 +109,35 @@ fn custom_value_paren<'a>(
                     acc
                 },
             ),
-            tag(end),
+            cut(char(end)),
         ),
         |mut parts| {
             parts.push(StringPart::Raw(end.into()));
             parts
         },
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn sass_string_ext(input: Span) -> PResult<SassString> {
     let (input, parts) =
-        many1(alt((string_part_interpolation, extended_part)))(input)?;
+        many1(alt((string_part_interpolation, extended_part)))
+            .parse(input)?;
     Ok((input, SassString::new(parts, Quotes::None)))
 }
 
 fn unquoted_first_part(input: Span) -> PResult<String> {
     let (input, first) = alt((
-        map(selector_plain_part, String::from),
+        map(str_plain_part, String::from),
         normalized_first_escaped_char,
         map(hash_no_interpolation, String::from),
-    ))(input)?;
+    ))
+    .parse(input)?;
     fold_many0(
         // Note: This could probably be a whole lot more efficient,
         // but try to get stuff correct before caring too much about that.
         alt((
-            map(selector_plain_part, String::from),
+            map(str_plain_part, String::from),
             normalized_escaped_char,
             map(hash_no_interpolation, String::from),
         )),
@@ -144,14 +146,15 @@ fn unquoted_first_part(input: Span) -> PResult<String> {
             acc.push_str(&item);
             acc
         },
-    )(input)
+    )
+    .parse(input)
 }
 fn unquoted_part(input: Span) -> PResult<String> {
     fold_many1(
         // Note: This could probably be a whole lot more efficient,
         // but try to get stuff correct before caring too much about that.
         alt((
-            map(selector_plain_part, String::from),
+            map(str_plain_part, String::from),
             normalized_escaped_char,
             map(hash_no_interpolation, String::from),
         )),
@@ -160,7 +163,8 @@ fn unquoted_part(input: Span) -> PResult<String> {
             acc.push_str(&item);
             acc
         },
-    )(input)
+    )
+    .parse(input)
 }
 
 fn normalized_first_escaped_char(input: Span) -> PResult<String> {
@@ -193,11 +197,11 @@ fn normalized_escaped_char(input: Span) -> PResult<String> {
 /// so that it can end up beeing parsed as a normal function call.
 pub fn special_function_misc(input: Span) -> PResult<SassString> {
     let (input, (start, mut args, end)) = verify(
-        tuple((
+        (
             recognize(terminated(
                 alt((
                     map(
-                        tuple((
+                        (
                             opt(delimited(tag("-"), alphanumeric1, tag("-"))),
                             alt((
                                 tag("calc"),
@@ -205,20 +209,30 @@ pub fn special_function_misc(input: Span) -> PResult<SassString> {
                                 tag("env"),
                                 tag("expression"),
                             )),
-                        )),
+                        ),
+                        |_| (),
+                    ),
+                    map(
+                        preceded(
+                            tag("progid:"),
+                            many1(alt((
+                                map(tag("."), |_| ()),
+                                map(selector_string, |_| ()),
+                            ))),
+                        ),
                         |_| (),
                     ),
-                    map(preceded(tag("progid:"), selector_string), |_| ()),
                 )),
                 tag("("),
             )),
             special_args,
             alt((tag(")"), tag(""))),
-        )),
+        ),
         |(start, args, _end)| {
             start.fragment() != b"calc(" || args.is_interpolated()
         },
-    )(input)?;
+    )
+    .parse(input)?;
 
     args.prepend(from_utf8(start.fragment()).unwrap());
     args.append_str(from_utf8(end.fragment()).unwrap());
@@ -248,24 +262,25 @@ pub fn special_arg_parts(input: Span) -> PResult<Vec<StringPart>> {
         map(map_res(is_not("#()\"\\;\n "), input_to_str), |s| {
             vec![StringPart::from(s)]
         }),
-    )))(input)?;
+    )))
+    .parse(input)?;
     Ok((input, parts.into_iter().flatten().collect()))
 }
 
 pub fn special_url(input: Span) -> PResult<SassString> {
-    let (input, _start) = tag("url(")(input)?;
-    let (input, _trim) = many0(is_a(" "))(input)?;
+    let (input, _start) = tag("url(").parse(input)?;
+    let (input, _trim) = many0(is_a(" ")).parse(input)?;
     let (input, mut parts) = many1(alt((
         string_part_interpolation,
-        map(map_res(tag("\\)"), input_to_string), StringPart::Raw),
-        map(selector_string, StringPart::Raw),
+        map(unquoted_part, StringPart::Raw),
         map(
             map_res(is_a("\":.;,!+/="), input_to_string),
             StringPart::Raw,
         ),
-    )))(input)?;
-    let (input, _trim) = many0(is_a(" "))(input)?;
-    let (input, _end) = tag(")")(input)?;
+    )))
+    .parse(input)?;
+    let (input, _trim) = many0(is_a(" ")).parse(input)?;
+    let (input, _end) = tag(")").parse(input)?;
     parts.insert(0, "url(".into());
     parts.push(")".into());
     Ok((input, SassString::new(parts, Quotes::None)))
@@ -288,8 +303,9 @@ fn dq_parts(input: Span) -> PResult<Vec<StringPart>> {
             value(StringPart::Raw("'".to_string()), tag("'")),
             map(normalized_escaped_char_q, StringPart::Raw),
         ))),
-        tag("\""),
-    )(input)
+        char('"'),
+    )
+    .parse(input)
 }
 
 pub fn sass_string_sq(input: Span) -> PResult<SassString> {
@@ -304,8 +320,9 @@ pub fn sass_string_sq(input: Span) -> PResult<SassString> {
             value(StringPart::from(""), tag("\\\n")),
             map(normalized_escaped_char_q, StringPart::Raw),
         ))),
-        tag("'"),
-    )(input)?;
+        char('\''),
+    )
+    .parse(input)?;
     cleanup_escape_ws(&mut parts);
     Ok((input, SassString::new(parts, Quotes::Single)))
 }
@@ -349,13 +366,13 @@ fn normalized_escaped_char_q(input: Span) -> PResult<String> {
 
 pub fn string_part_interpolation(input: Span) -> PResult<StringPart> {
     let (input, expr) =
-        delimited(tag("#{"), value_expression, tag("}"))(input)?;
+        delimited(tag("#{"), value_expression, tag("}")).parse(input)?;
     Ok((input, StringPart::Interpolation(expr)))
 }
 
 fn simple_qstring_part(input: Span) -> PResult<StringPart> {
     let (input, part) =
-        map_res(is_not("\\#'\"\n\r"), input_to_string)(input)?;
+        map_res(is_not("\\#'\"\n\r\u{c}"), input_to_string).parse(input)?;
     Ok((input, StringPart::Raw(part)))
 }
 
@@ -364,7 +381,7 @@ fn selector_string(input: Span) -> PResult<String> {
         // Note: This could probably be a whole lot more efficient,
         // but try to get stuff correct before caring too much about that.
         alt((
-            map(selector_plain_part, String::from),
+            selector_plain_part,
             map(tag("\\ "), |_| "\\ ".to_string()),
             map(tag("\\\""), |_| "\\\"".to_string()),
             map(tag("\\\'"), |_| "\\\'".to_string()),
@@ -377,18 +394,33 @@ fn selector_string(input: Span) -> PResult<String> {
             acc.push_str(&item);
             acc
         },
-    )(input)
+    )
+    .parse(input)
 }
 
-fn selector_plain_part(input: Span) -> PResult<&str> {
-    // TODO: This should include "%", but then it needs to be handled
-    // specially for keyframes percentages and placeholder selectors.
-    // Also TODO: This should probably be based on unicode alphanumeric.
-    map_res(is_not("\r\n\t <>$\"'\\#+*/()[]{}:;,=!&@"), input_to_str)(input)
+fn selector_plain_part(input: Span) -> PResult<String> {
+    fold_many1(
+        verify(take_char, |ch| {
+            ch.is_alphanumeric() || *ch == '-' || *ch == '_'
+        }),
+        String::new,
+        |mut acc, chr: char| {
+            acc.push(chr);
+            acc
+        },
+    )
+    .parse(input)
+}
+
+fn str_plain_part(input: Span) -> PResult<&str> {
+    // TODO: This should probably be based on unicode alphanumeric.
+    map_res(is_not("\r\n\t %<>$\"'\\#+*/()[]{}:;,=!&@~"), input_to_str)
+        .parse(input)
 }
 
 fn hash_no_interpolation(input: Span) -> PResult<&str> {
-    map_res(terminated(tag("#"), peek(not(tag("{")))), input_to_str)(input)
+    map_res(terminated(tag("#"), peek(not(tag("{")))), input_to_str)
+        .parse(input)
 }
 
 pub fn extended_part(input: Span) -> PResult<StringPart> {
@@ -398,7 +430,8 @@ pub fn extended_part(input: Span) -> PResult<StringPart> {
             many0(verify(take_char, is_ext_str_char)),
         )),
         input_to_string,
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, StringPart::Raw(part)))
 }
 
@@ -412,6 +445,8 @@ fn is_ext_str_start_char(c: &char) -> bool {
         || *c == '='
         || *c == '?'
         || *c == '|'
+        || *c == '<'
+        || *c == '>'
 }
 fn is_ext_str_char(c: &char) -> bool {
     is_name_char(c)
@@ -424,25 +459,33 @@ fn is_ext_str_char(c: &char) -> bool {
         || *c == '='
         || *c == '?'
         || *c == '|'
+        || *c == '<'
+        || *c == '>'
+        || *c == '\\'
 }
 
 pub fn name(input: Span) -> PResult<String> {
+    let (input, first) =
+        verify(alt((escaped_char, take_char)), is_name_start_char)
+            .parse(input)?;
     verify(
         fold_many0(
             alt((escaped_char, name_char)),
-            String::new,
+            move || String::from(first),
             |mut s, c| {
                 s.push(c);
                 s
             },
         ),
         |s: &str| !s.is_empty() && s != "-",
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn unitname(input: Span) -> PResult<String> {
     let (input, first) =
-        verify(alt((escaped_char, name_char)), |c| c.is_alphabetic())(input)?;
+        verify(alt((escaped_char, name_char)), |c| c.is_alphabetic())
+            .parse(input)?;
     fold_many0(
         verify(alt((escaped_char, name_char)), |c| c.is_alphanumeric()),
         move || first.to_string(),
@@ -450,11 +493,12 @@ pub fn unitname(input: Span) -> PResult<String> {
             s.push(c);
             s
         },
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn name_char(input: Span) -> PResult<char> {
-    verify(take_char, is_name_char)(input)
+    verify(take_char, is_name_char).parse(input)
 }
 
 fn escaped_char(input: Span) -> PResult<char> {
@@ -463,25 +507,36 @@ fn escaped_char(input: Span) -> PResult<char> {
         alt((
             value('\\', tag("\\")),
             map_opt(
-                map_res(
-                    map_res(
-                        terminated(
-                            recognize(many_m_n(
-                                1,
-                                6,
-                                one_of("0123456789ABCDEFabcdef"),
-                            )),
-                            opt(tag(" ")),
+                pair(
+                    recognize(many_m_n(
+                        1,
+                        6,
+                        one_of("0123456789ABCDEFabcdef"),
+                    )),
+                    alt((
+                        value(true, tag(" ")),
+                        value(
+                            true,
+                            peek(not(one_of("0123456789ABCDEFabcdef"))),
                         ),
-                        input_to_str,
-                    ),
-                    |s| u32::from_str_radix(s, 16),
+                        value(false, tag("")),
+                    )),
                 ),
-                std::char::from_u32,
+                |(code, term): (Span, bool)| {
+                    if term || code.len() == 6 {
+                        std::char::from_u32(
+                            u32::from_str_radix(input_to_str(code).ok()?, 16)
+                                .ok()?,
+                        )
+                    } else {
+                        None
+                    }
+                },
             ),
             take_char,
         )),
-    )(input)
+    )
+    .parse(input)
 }
 
 fn take_char(input: Span) -> PResult<char> {
@@ -491,7 +546,8 @@ fn take_char(input: Span) -> PResult<char> {
         map_opt(take(3usize), single_char),
         map_opt(take(4usize), single_char),
         map_opt(take(5usize), single_char),
-    ))(input)
+    ))
+    .parse(input)
 }
 
 fn single_char(data: Span) -> Option<char> {
@@ -503,3 +559,6 @@ fn single_char(data: Span) -> Option<char> {
 fn is_name_char(c: &char) -> bool {
     c.is_alphanumeric() || *c == '_' || *c == '-'
 }
+fn is_name_start_char(c: &char) -> bool {
+    c.is_alphabetic() || *c == '_' || *c == '-'
+}
