@@ -2,6 +2,7 @@ use super::strings::unitname;
 use super::{PResult, Span};
 use crate::value::Unit;
 use nom::combinator::{map, value};
+use nom::Parser as _;
 use nom::{branch::alt, bytes::complete::tag};
 
 pub fn unit(input: Span) -> PResult<Unit> {
@@ -50,5 +51,6 @@ pub fn unit(input: Span) -> PResult<Unit> {
             name => Unit::Unknown(name.to_string()),
         }),
         value(Unit::None, tag("")),
-    ))(input)
+    ))
+    .parse(input)
 }
