@@ -2,7 +2,7 @@ use super::css_function::css_function;
 use super::formalargs::call_args;
 use super::strings::{
     name, sass_string_dq, sass_string_ext, sass_string_sq,
-    special_function_misc, special_url, var_name,
+    special_function_misc, special_url,
 };
 use super::unit::unit;
 use super::util::{ignore_comments, opt_spacelike, spacelike2};
@@ -10,27 +10,31 @@ use super::{
     input_to_string, list_or_single, position, sass_string, PResult, Span,
 };
 use crate::sass::{BinOp, SassString, Value};
-use crate::value::{ListSeparator, Number, Numeric, Operator, Rgba};
+use crate::value::{ListSeparator, Numeric, Operator, Rgba};
 use nom::branch::alt;
 use nom::bytes::complete::{tag, tag_no_case};
 use nom::character::complete::{
-    alphanumeric1, multispace0, multispace1, one_of,
+    alphanumeric1, char, digit1, multispace0, multispace1, one_of,
 };
 use nom::combinator::{
-    into, map, map_res, not, opt, peek, recognize, value, verify,
+    cut, into, map, map_opt, map_res, not, opt, peek, recognize, value,
+    verify,
 };
-use nom::multi::{fold_many0, fold_many1, many0, many_m_n, separated_list1};
-use nom::sequence::{delimited, pair, preceded, terminated, tuple};
-use num_traits::Zero;
+use nom::error::context;
+use nom::multi::{fold_many0, many0, many_m_n, separated_list1};
+use nom::sequence::{delimited, pair, preceded, terminated};
+use nom::Parser as _;
 use std::str::from_utf8;
 
 pub fn value_expression(input: Span) -> PResult<Value> {
     let (input, result) = separated_list1(
         preceded(tag(","), ignore_comments),
         terminated(space_list, ignore_comments),
-    )(input)?;
+    )
+    .parse(input)?;
     let (input, trail) =
-        many0(delimited(opt_spacelike, tag(","), opt_spacelike))(input)?;
+        many0(delimited(opt_spacelike, tag(","), opt_spacelike))
+            .parse(input)?;
     Ok((
         input,
         if result.len() == 1 && trail.is_empty() {
@@ -61,7 +65,8 @@ pub fn space_list(input: Span) -> PResult<Value> {
             }
             list
         },
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, list_or_single(list, ListSeparator::Space)))
 }
 
@@ -74,18 +79,25 @@ pub fn simple_space_list(input: Span) -> PResult<Value> {
             list.push(item);
             list
         },
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, list_or_single(list, ListSeparator::Space)))
 }
 
 fn se_or_ext_string(input: Span) -> PResult<Value> {
-    alt((single_expression, map(sass_string_ext, Value::Literal)))(input)
+    let result = single_expression(input);
+    if matches!(result, Err(nom::Err::Error(_))) {
+        if let Ok((rest, lit)) = sass_string_ext(input) {
+            return Ok((rest, Value::Literal(lit)));
+        }
+    }
+    result
 }
 
 fn single_expression(input: Span) -> PResult<Value> {
     let (input1, a) = logic_expression(input)?;
     fold_many0(
-        tuple((
+        (
             delimited(
                 multispace0,
                 alt((
@@ -96,29 +108,31 @@ fn single_expression(input: Span) -> PResult<Value> {
             ),
             single_expression,
             position,
-        )),
+        ),
         move || a.clone(),
         |a, (op, b, end)| {
             let pos = input.up_to(&end).to_owned();
             BinOp::new(a, false, op, false, b, pos).into()
         },
-    )(input1)
+    )
+    .parse(input1)
 }
 
 fn logic_expression(input: Span) -> PResult<Value> {
     let (input1, a) = sum_expression(input)?;
     fold_many0(
-        tuple((
+        (
             delimited(multispace0, relational_operator, multispace0),
             sum_expression,
             position,
-        )),
+        ),
         move || a.clone(),
         |a, (op, b, end)| {
             let pos = input.up_to(&end).to_owned();
             BinOp::new(a, true, op, true, b, pos).into()
         },
-    )(input1)
+    )
+    .parse(input1)
 }
 
 fn relational_operator(input: Span) -> PResult<Operator> {
@@ -129,7 +143,8 @@ fn relational_operator(input: Span) -> PResult<Operator> {
         value(Operator::Greater, tag(">")),
         value(Operator::LesserE, tag("<=")),
         value(Operator::Lesser, tag("<")),
-    ))(input)
+    ))
+    .parse(input)
 }
 
 fn sum_expression(input: Span) -> PResult<Value> {
@@ -143,18 +158,18 @@ where
     let (rest, v) = term(input)?;
     fold_many0(
         verify(
-            tuple((
-                tuple((
+            (
+                (
                     ignore_comments,
                     alt((
                         value(Operator::Plus, tag("+")),
                         value(Operator::Minus, tag("-")),
                     )),
                     ignore_comments,
-                )),
+                ),
                 term,
                 position,
-            )),
+            ),
             |((s1, op, s2), t2, _)| {
                 use Value::*;
                 *s2 || !*s1
@@ -167,7 +182,8 @@ where
             let pos = input.up_to(&end).to_owned();
             BinOp::new(v, s1, op, s2, v2, pos).into()
         },
-    )(rest)
+    )
+    .parse(rest)
 }
 
 fn term_value(input: Span) -> PResult<Value> {
@@ -180,7 +196,7 @@ where
 {
     let (rest, v) = factor(input)?;
     fold_many0(
-        tuple((
+        (
             ignore_comments,
             alt((
                 value(Operator::Multiply, tag("*")),
@@ -193,23 +209,25 @@ where
             ignore_comments,
             factor,
             position,
-        )),
+        ),
         move || v.clone(),
         |v1, (s1, op, s2, v2, end)| {
             let pos = input.up_to(&end).to_owned();
             BinOp::new(v1, s1, op, s2, v2, pos).into()
         },
-    )(rest)
+    )
+    .parse(rest)
 }
 
 pub fn single_value(input: Span) -> PResult<Value> {
     match input.first() {
         Some(b'!') => bang(input),
-        Some(b'&') => value(Value::HereSelector, tag("&"))(input),
-        Some(b'"') => map(sass_string_dq, Value::Literal)(input),
-        Some(b'\'') => map(sass_string_sq, Value::Literal)(input),
+        Some(b'&') => value(Value::HereSelector, tag("&")).parse(input),
+        Some(b'"') => map(sass_string_dq, Value::Literal).parse(input),
+        Some(b'\'') => map(sass_string_sq, Value::Literal).parse(input),
         Some(b'[') => bracket_list(input),
         Some(b'(') => value_in_parens(input),
+        Some(b'$') => variable_nomod(input),
         _ => alt((
             value(Value::True, tag("true")),
             value(Value::False, tag("false")),
@@ -220,12 +238,10 @@ pub fn single_value(input: Span) -> PResult<Value> {
             value(Value::Null, tag("null")),
             map(special_url, Value::Literal),
             special_function,
-            // Really ugly special case ... sorry.
-            value(Value::Literal("-null".into()), tag("-null")),
-            map(var_name, Value::Literal),
-            unary_op,
             function_call_or_string,
-        ))(input),
+            unary_op,
+        ))
+        .parse(input),
     }
 }
 
@@ -234,30 +250,32 @@ fn bang(input: Span) -> PResult<Value> {
         map_res(
             preceded(
                 pair(tag("!"), opt_spacelike),
-                tag("important"), // TODO Pretty much anythig goes, here?
+                context("Expected \"important\".", tag("important")),
             ),
             input_to_string,
         ),
         Value::Bang,
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn value_in_parens(input: Span) -> PResult<Value> {
-    let (input0, _p) = preceded(tag("("), opt_spacelike)(input)?;
+    let (input0, _p) = preceded(tag("("), opt_spacelike).parse(input)?;
     if let Ok((input, first_key)) = simple_space_list(input0) {
         let (input, value) = if let Ok((mut input, first_val)) =
-            preceded(colon, space_list)(input)
+            preceded(colon, space_list).parse(input)
         {
             let mut items = vec![(first_key, first_val)];
             while let Ok((rest, (key, val))) = pair(
                 preceded(comma, simple_space_list),
                 preceded(colon, space_list),
-            )(input)
+            )
+            .parse(input)
             {
                 items.push((key, val));
                 input = rest;
             }
-            let (input, _) = opt(comma)(input)?;
+            let (input, _) = opt(comma).parse(input)?;
             (input, Value::Map(items))
         } else {
             (input, Value::Paren(Box::new(first_key), false))
@@ -272,31 +290,34 @@ pub fn value_in_parens(input: Span) -> PResult<Value> {
             map(tag(""), |_| Value::List(vec![], None, false)),
         )),
         end_paren,
-    )(input0)
+    )
+    .parse(input0)
 }
 
 fn comma(input: Span) -> PResult<Span> {
-    delimited(opt_spacelike, tag(","), opt_spacelike)(input)
+    delimited(opt_spacelike, tag(","), opt_spacelike).parse(input)
 }
 
 fn colon(input: Span) -> PResult<Span> {
-    delimited(opt_spacelike, tag(":"), opt_spacelike)(input)
+    delimited(opt_spacelike, tag(":"), opt_spacelike).parse(input)
 }
 
 fn end_paren(input: Span) -> PResult<Span> {
-    preceded(opt_spacelike, tag(")"))(input)
+    preceded(opt_spacelike, tag(")")).parse(input)
 }
 
 fn unicode_range(input: Span) -> PResult<Value> {
-    map(unicode_range_inner, Value::UnicodeRange)(input)
+    map(unicode_range_inner, Value::UnicodeRange).parse(input)
 }
 pub(crate) fn unicode_range_inner(input: Span) -> PResult<String> {
-    let (rest, _) = tag_no_case("U+")(input)?;
-    let (rest, a) = many_m_n(0, 6, one_of("0123456789ABCDEFabcdef"))(rest)?;
+    let (rest, _) = tag_no_case("U+").parse(input)?;
+    let (rest, a) =
+        many_m_n(0, 6, one_of("0123456789ABCDEFabcdef")).parse(rest)?;
     let (rest, _) = alt((
         preceded(tag("-"), many_m_n(1, 6, one_of("0123456789ABCDEFabcdef"))),
         many_m_n(0, 6 - a.len(), one_of("?")),
-    ))(rest)?;
+    ))
+    .parse(rest)?;
     let length = rest.location_offset() - input.location_offset();
     let matched = &input.fragment()[0..length];
     // The unwrap should be ok, as only ascii is matched.
@@ -305,7 +326,8 @@ pub(crate) fn unicode_range_inner(input: Span) -> PResult<String> {
 
 pub fn bracket_list(input: Span) -> PResult<Value> {
     let (input, content) =
-        delimited(tag("["), opt(value_expression), tag("]"))(input)?;
+        delimited(char('['), opt(value_expression), char(']'))
+            .parse(input)?;
     Ok((
         input,
         match content {
@@ -318,94 +340,40 @@ pub fn bracket_list(input: Span) -> PResult<Value> {
     ))
 }
 
-fn sign_prefix(input: Span) -> PResult<Option<&[u8]>> {
-    opt(alt((tag("-"), tag("+"))))(input)
-        .map(|(r, s)| (r, s.map(|s| s.fragment())))
-}
-
 pub fn numeric(input: Span) -> PResult<Numeric> {
     map(pair(number, unit), |(number, unit)| {
         Numeric::new(number, unit)
-    })(input)
+    })
+    .parse(input)
 }
 
-pub fn number(input: Span) -> PResult<Number> {
-    map(
-        tuple((
-            sign_prefix,
+pub fn number(input: Span) -> PResult<f64> {
+    map_opt(
+        recognize(delimited(
+            opt(one_of("+-")),
             alt((
-                map(pair(decimal_integer, decimal_decimals), |(n, d)| n + d),
-                decimal_decimals,
-                decimal_integer,
-            )),
-            opt(preceded(
-                alt((tag("e"), tag("E"))),
-                tuple((sign_prefix, decimal_i32)),
+                terminated(digit1, opt(terminated(char('.'), digit1))),
+                preceded(char('.'), digit1),
             )),
+            opt(delimited(one_of("eE"), opt(one_of("+-")), digit1)),
         )),
-        |(sign, num, exp)| {
-            let value = if sign == Some(b"-") {
-                // Only f64-based Number can represent negative zero.
-                if num.is_zero() {
-                    (-0.0).into()
-                } else {
-                    -num
-                }
-            } else {
-                num
-            };
-            if let Some((e_sign, e_val)) = exp {
-                let e_val = if e_sign == Some(b"-") { -e_val } else { e_val };
-                // Note: powi sounds right, but looses some precision.
-                value * Number::from(10f64.powf(e_val.into()))
-            } else {
-                value
-            }
-        },
-    )(input)
+        |s: Span| from_utf8(s.fragment()).ok()?.parse().ok(),
+    )
+    .parse(input)
 }
 
-pub fn decimal_integer(input: Span) -> PResult<Number> {
-    fold_many1(
-        // Note: We should use bytes directly, one_of returns a char.
-        one_of("0123456789"),
-        || Number::from(0),
-        |r, d| (r * 10) + Number::from(i64::from(d as u8 - b'0')),
-    )(input)
-}
-pub fn decimal_i32(input: Span) -> PResult<i32> {
-    fold_many1(
-        // Note: We should use bytes directly, one_of returns a char.
-        one_of("0123456789"),
-        || 0,
-        |r, d| (r * 10) + i32::from(d as u8 - b'0'),
-    )(input)
-}
-
-pub fn decimal_decimals(input: Span) -> PResult<Number> {
-    map(
-        preceded(
-            tag("."),
-            fold_many1(
-                one_of("0123456789"),
-                || (Number::from(0), Number::from(1)),
-                |(r, n), d| {
-                    (
-                        (r * 10) + Number::from(i64::from(d as u8 - b'0')),
-                        n * 10,
-                    )
-                },
-            ),
-        ),
-        |(r, d)| r / d,
-    )(input)
+pub fn variable_nomod(input: Span) -> PResult<Value> {
+    let (rest, name) = preceded(char('$'), identifier).parse(input)?;
+    let pos = input.up_to(&rest).to_owned();
+    Ok((rest, Value::Variable(name.into(), pos)))
 }
 
 pub fn variable(input: Span) -> PResult<Value> {
     let (rest, (modules, name)) = pair(
         many0(terminated(name, tag("."))),
-        preceded(tag("$"), name),
-    )(input)?;
+        preceded(tag("$"), cut(identifier)),
+    )
+    .parse(input)?;
     let name = if modules.is_empty() {
         name
     } else {
@@ -415,15 +383,20 @@ pub fn variable(input: Span) -> PResult<Value> {
     Ok((rest, Value::Variable(name.into(), pos)))
 }
 
+pub fn identifier(input: Span) -> PResult<String> {
+    context("Expected identifier.", name).parse(input)
+}
+
 fn hex_color(input: Span) -> PResult<Value> {
     let (rest, (r, g, b, a)) = delimited(
         tag("#"),
         alt((
-            tuple((hexchar2, hexchar2, hexchar2, opt(hexchar2))),
-            tuple((hexchar1, hexchar1, hexchar1, opt(hexchar1))),
+            (hexchar2, hexchar2, hexchar2, opt(hexchar2)),
+            (hexchar1, hexchar1, hexchar1, opt(hexchar1)),
         )),
         peek(map(not(alphanumeric1), |_| ())),
-    )(input)?;
+    )
+    .parse(input)?;
 
     if let Some(a) = a {
         let rgba = Rgba::from_rgba(r, g, b, a);
@@ -440,7 +413,7 @@ fn hex_color(input: Span) -> PResult<Value> {
 
 pub fn unary_op(input: Span) -> PResult<Value> {
     map(
-        tuple((
+        (
             alt((
                 value(Operator::Plus, tag("+")),
                 value(Operator::Minus, tag("-")),
@@ -449,7 +422,7 @@ pub fn unary_op(input: Span) -> PResult<Value> {
             )),
             ignore_comments,
             single_value,
-        )),
+        ),
         |(op, s, v)| match (op, s, v) {
             (
                 Operator::Minus | Operator::Plus,
@@ -461,41 +434,74 @@ pub fn unary_op(input: Span) -> PResult<Value> {
             }
             (op, _, v) => Value::UnaryOp(op, Box::new(v)),
         },
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn special_function(input: Span) -> PResult<Value> {
     // Either a nice semantic css function or a fallback with interpolation.
-    alt((css_function, map(special_function_misc, Value::Literal)))(input)
+    alt((css_function, map(special_function_misc, Value::Literal)))
+        .parse(input)
 }
 
 pub fn function_call_or_string(input: Span) -> PResult<Value> {
+    function_call_or_string_real(input, true)
+}
+pub fn function_call_or_string_rulearg(input: Span) -> PResult<Value> {
+    function_call_or_string_real(input, false)
+}
+fn function_call_or_string_real(
+    input: Span,
+    allow_not: bool,
+) -> PResult<Value> {
     let (rest, name) = sass_string(input)?;
-    /* TODO: true, false and null should end up here, but can't as long as '.' is a normal part of a string.
-    if let Some(special) = name.single_raw().and_then(|s| match s {
-        "true" => return Some(Value::True),
-        "false" => return Some(Value::False),
-        "null" => return Some(Value::Null),
-        _ => None,
-    }) {
-        return Ok((rest, special));
+
+    if let Some(val) = name.single_raw() {
+        match val {
+            "not" if allow_not => {
+                if let Ok((rest, arg)) =
+                    preceded(ignore_comments, single_value).parse(rest)
+                {
+                    return Ok((
+                        rest,
+                        Value::UnaryOp(Operator::Not, Box::new(arg)),
+                    ));
+                }
+            }
+            "NaN" => return Ok((rest, Value::scalar(f64::NAN))),
+            "infinity" => return Ok((rest, Value::scalar(f64::INFINITY))),
+            "-infinity" => {
+                return Ok((rest, Value::scalar(f64::NEG_INFINITY)))
+            }
+
+            /* TODO: true, false and null should end up here, but can't as long as '.' is a normal part of a string.
+            "true" => return Ok((rest, Value::True)),
+            "false" => return Ok((rest, Value::False)),
+            "null" => return Ok((rest, Value::Null)),
+             */
+            _ => (),
+        }
     }
-     */
-    if let Ok((rest, args)) = call_args(rest) {
-        let pos = input.up_to(&rest).to_owned();
-        return Ok((rest, Value::Call(name, args, pos)));
+    if rest.starts_with(b"(") {
+        match call_args(rest) {
+            Ok((rest, args)) => {
+                let pos = input.up_to(&rest).to_owned();
+                return Ok((rest, Value::Call(name, args, pos)));
+            }
+            Err(error) => {
+                if let Ok((rest, lit)) = sass_string_ext(rest) {
+                    return Ok((rest, Value::Literal(lit)));
+                } else {
+                    return Err(error);
+                }
+            }
+        }
     }
     Ok((rest, literal_or_color(name)))
 }
 
 fn literal_or_color(s: SassString) -> Value {
     if let Some(val) = s.single_raw() {
-        if val == "infinity" {
-            return Value::scalar(f64::INFINITY);
-        }
-        if val == "NaN" {
-            return Value::scalar(f64::NAN);
-        }
         if let Some(rgba) = Rgba::from_name(val) {
             return Value::Color(rgba, Some(val.to_string()));
         }
@@ -504,15 +510,17 @@ fn literal_or_color(s: SassString) -> Value {
 }
 
 fn hexchar1(input: Span) -> PResult<u8> {
-    map(hexchar_raw, |one| one * 0x11)(input)
+    map(hexchar_raw, |one| one * 0x11).parse(input)
 }
 fn hexchar2(input: Span) -> PResult<u8> {
-    map(pair(hexchar_raw, hexchar_raw), |(hi, lo)| hi * 0x10 + lo)(input)
+    map(pair(hexchar_raw, hexchar_raw), |(hi, lo)| hi * 0x10 + lo)
+        .parse(input)
 }
 fn hexchar_raw(input: Span) -> PResult<u8> {
     map(one_of("0123456789ABCDEFabcdef"), |ch| {
         ch.to_digit(16).unwrap() as u8
-    })(input)
+    })
+    .parse(input)
 }
 
 pub fn dictionary(input: Span) -> PResult<Value> {
@@ -520,7 +528,8 @@ pub fn dictionary(input: Span) -> PResult<Value> {
         preceded(tag("("), opt_spacelike),
         dictionary_inner,
         terminated(opt_spacelike, tag(")")),
-    )(input)
+    )
+    .parse(input)
 }
 
 pub fn dictionary_inner(input: Span) -> PResult<Value> {
@@ -536,7 +545,8 @@ pub fn dictionary_inner(input: Span) -> PResult<Value> {
             ),
         ),
         opt(delimited(opt_spacelike, tag(","), opt_spacelike)),
-    )(input)?;
+    )
+    .parse(input)?;
     Ok((input, Value::Map(items.into_iter().collect())))
 }
 
@@ -546,43 +556,38 @@ mod test {
     use super::*;
     use crate::sass::CallArgs;
     use crate::sass::Value::{Color, List, Literal, Map, Paren};
-    use crate::value::Rational;
     use crate::ScopeRef;
 
     #[test]
     fn simple_number() {
-        check_expr("4;", number(4, 1))
+        check_expr("4;", Value::scalar(4.))
     }
 
     #[test]
     fn simple_number_neg() {
-        check_expr("-4;", number(-4, 1))
+        check_expr("-4;", Value::scalar(-4.))
     }
 
     #[test]
     fn simple_number_pos() {
-        check_expr("+4;", Value::scalar(4))
+        check_expr("+4;", Value::scalar(4.))
     }
 
     #[test]
     fn simple_number_dec() {
-        check_expr("4.34;", number(434, 100))
+        check_expr("4.34;", Value::scalar(4.34))
     }
     #[test]
     fn simple_number_onlydec() {
-        check_expr(".34;", number(34, 100))
+        check_expr(".34;", Value::scalar(0.34))
     }
     #[test]
     fn simple_number_onlydec_neg() {
-        check_expr("-.34;", number(-34, 100))
+        check_expr("-.34;", Value::scalar(-0.34))
     }
     #[test]
     fn simple_number_onlydec_pos() {
-        check_expr("+.34;", number(34, 100))
-    }
-
-    fn number(nom: i64, denom: i64) -> Value {
-        Value::scalar(Rational::new(nom, denom))
+        check_expr("+.34;", Value::scalar(0.34))
     }
 
     #[test]
