@@ -1,14 +1,13 @@
 use super::{
-    expected_to, is_not, is_special, CallError, CheckedArg, FunctionMap,
+    expected_to, is_not, CallError, CheckedArg, FunctionMap, NumOrSpecial,
     ResolvedArgs,
 };
 use crate::css::{CallArgs, CssString, Value};
 use crate::input::SourcePos;
 use crate::output::Format;
 use crate::sass::{FormalArgs, Name};
-use crate::value::{ListSeparator, Number, Numeric, Quotes, Rational, Unit};
+use crate::value::{ListSeparator, Numeric, Quotes, Unit};
 use crate::Scope;
-use num_traits::{one, zero, Signed};
 mod channels;
 mod hsl;
 mod hwb;
@@ -55,45 +54,44 @@ pub fn create_module() -> Scope {
 pub fn expose(m: &Scope, global: &mut FunctionMap) {
     rgb::expose(m, global);
     hsl::expose(m, global);
+    hwb::expose(m, global);
     other::expose(m, global);
 }
 
 /// For the alpha parameter of rgba, hsla, hwba functions
 /// Special perk: Defaults to 1.0 if the value is null.
-fn check_alpha(v: Value) -> Result<Rational, String> {
+fn check_alpha(v: Value) -> Result<f64, String> {
     Ok(match v {
-        Value::Null => one(),
+        Value::Null => 1.0,
         v => {
             let num = Numeric::try_from(v)?;
             num.as_unit(Unit::None)
                 .ok_or_else(|| {
                     expected_to(num, "have unit \"%\" or no units")
                 })?
-                .as_ratio()?
+                .into()
         }
     })
 }
 /// Get a rational number in the 0..1 range.
-fn check_alpha_range(v: Value) -> Result<Rational, String> {
+fn check_alpha_range(v: Value) -> Result<f64, String> {
     let v = Numeric::try_from(v)?;
-    let r = v.as_ratio()?;
-    if r < zero() || r > one() {
+    if v.value < 0.into() || v.value > 1.into() {
         Err(expected_to(v, "be within 0 and 1"))
     } else {
-        Ok(r)
+        Ok(v.value.into())
     }
 }
-fn check_alpha_pm(v: Value) -> Result<Rational, String> {
+fn check_alpha_pm(v: Value) -> Result<f64, String> {
     let v = Numeric::try_from(v)?;
-    let r = v.as_ratio()?;
-    if r.abs() > one() {
+    if v.value.abs() > 1.into() {
         Err(expected_to(v, "be within -1 and 1"))
     } else {
-        Ok(r)
+        Ok(v.value.into())
     }
 }
 
-fn check_hue(v: Value) -> Result<Rational, String> {
+fn check_hue(v: Value) -> Result<f64, String> {
     let v = Numeric::try_from(v)?;
     let v = match v.as_unit_def(Unit::Deg) {
         Some(v) => v,
@@ -108,13 +106,13 @@ fn check_hue(v: Value) -> Result<Rational, String> {
             v.value
         }
     };
-    v.as_ratio().map_err(|e| e.to_string())
+    Ok(v.into())
 }
 
-fn check_pct(v: Value) -> Result<Number, String> {
+fn check_pct(v: Value) -> Result<f64, String> {
     let val = Numeric::try_from(v)?;
     match val.as_unit_def(Unit::Percent) {
-        Some(v) => Ok(v),
+        Some(v) => Ok(f64::from(v) / 100.),
         None => {
             dep_warn!(
                 "Passing a number without unit % ({}) is deprecated.\
@@ -123,83 +121,85 @@ fn check_pct(v: Value) -> Result<Number, String> {
                 val.format(Format::introspect()),
                 val.unit
             );
-            Ok(val.value)
+            Ok(f64::from(val.value) / 100.)
         }
     }
 }
 
-fn check_expl_pct(v: Value) -> Result<Rational, String> {
+fn check_expl_pct_norange(v: Value) -> Result<f64, String> {
+    let val = Numeric::try_from(v)?;
+    if !val.unit.is_percent() {
+        Err(expected_to(val, "have unit \"%\""))
+    } else {
+        Ok(f64::from(val.value) / 100.)
+    }
+}
+fn check_expl_pct(v: Value) -> Result<f64, String> {
     let val = Numeric::try_from(v)?;
     if !val.unit.is_percent() {
         return Err(expected_to(val, "have unit \"%\""));
     }
-    if val.value < zero() || val.value > 100.into() {
+    if val.value < 0.into() || val.value > 100.into() {
         Err(expected_to(val, "be within 0% and 100%"))
     } else {
-        Ok(val.as_ratio()? / 100)
+        Ok(f64::from(val.value) / 100.)
     }
 }
 
-fn check_pct_range(v: Value) -> Result<Rational, String> {
+fn check_pct_range(v: Value) -> Result<f64, String> {
     let val = check_pct(v)?;
-    if val < zero() || val > 100.into() {
+    if val < 0.into() || val > 1.into() {
         Err(expected_to(
-            Numeric::new(val, Unit::Percent),
+            Numeric::percentage(val),
             "be within 0% and 100%",
         ))
     } else {
-        Ok(val.as_ratio()? / 100)
+        Ok(val)
     }
 }
 
-fn check_amount(v: Value) -> Result<Rational, String> {
+fn check_amount(v: Value) -> Result<f64, String> {
     let val = check_pct(v)?;
-    if val < zero() || val > 100.into() {
-        Err(expected_to(Value::scalar(val), "be within 0 and 100"))
+    if val < 0.into() || val > 1.into() {
+        Err(expected_to(
+            Value::scalar(val * 100.),
+            "be within 0 and 100",
+        ))
     } else {
-        Ok(val.as_ratio()? / 100)
+        Ok(val)
     }
 }
 
-fn check_channel(v: Value) -> Result<Rational, String> {
+fn check_channel(v: Value) -> Result<f64, String> {
     num2chan(&Numeric::try_from(v)?)
 }
-fn check_channel_range(v: Value) -> Result<Rational, String> {
+fn check_channel_range(v: Value) -> Result<f64, String> {
     let v = Numeric::try_from(v)?;
     let r = num2chan(&v)?;
-    if r > Rational::from_integer(255) || r < zero() {
-        Err(expected_to(v, "be within 0 and 255"))
-    } else {
+    if (0. ..=255.).contains(&r) {
         Ok(r)
+    } else {
+        Err(expected_to(v, "be within 0 and 255"))
     }
 }
-fn check_channel_pm(v: Value) -> Result<Rational, String> {
+fn check_channel_pm(v: Value) -> Result<f64, String> {
     let v = Numeric::try_from(v)?;
     let r = num2chan(&v)?;
-    if r.abs() > Rational::from_integer(255) {
+    if r.abs() > 255. {
         Err(expected_to(v, "be within -255 and 255"))
     } else {
         Ok(r)
     }
 }
-fn num2chan(v: &Numeric) -> Result<Rational, String> {
-    let r = v.as_ratio()?;
+fn num2chan(v: &Numeric) -> Result<f64, String> {
+    let r = f64::from(v.value.clone());
     if v.unit.is_percent() {
-        Ok(r * 255 / 100)
+        Ok(r * 255. / 100.)
     } else {
         Ok(r)
     }
 }
 
-fn make_call(name: &str, args: Vec<Value>) -> Value {
-    Value::Call(
-        name.into(),
-        CallArgs::from_list(
-            args.into_iter().filter(|v| v != &Value::Null).collect(),
-        ),
-    )
-}
-
 pub(crate) fn eval_inner(
     name: &Name,
     decl: &FormalArgs,
@@ -243,3 +243,10 @@ fn relative_color(args: &CallArgs) -> bool {
     }
     args.get_single().map(inner).unwrap_or(false)
 }
+
+fn is_special(v: &Value) -> bool {
+    matches!(
+        NumOrSpecial::try_from(v.clone()),
+        Ok(NumOrSpecial::Special(_))
+    )
+}
