@@ -1,5 +1,5 @@
 use super::{
-    CallArgs, Callable, Name, SassString, Selectors, Value,
+    CallArgs, Callable, Name, SassString, Selectors, SrcRange, Value,
     VariableDeclaration,
 };
 use crate::input::SourcePos;
@@ -62,18 +62,7 @@ pub enum Item {
     /// The value may be or evaluate to a list.
     Each(Vec<Name>, Value, Vec<Item>),
     /// An `@for` loop directive.
-    For {
-        /// The name of the iteration variable.
-        name: Name,
-        /// The start value for the iteration.
-        from: Box<Value>,
-        /// The end value for the iteration.
-        to: Box<Value>,
-        /// True if the end should be included in the range.
-        inclusive: bool,
-        /// The body of the loop.
-        body: Vec<Item>,
-    },
+    For(Name, SrcRange, Vec<Item>),
     /// An `@while` loop directive.
     While(Value, Vec<Item>),
 
@@ -108,7 +97,7 @@ pub enum Item {
 
 impl From<VariableDeclaration> for Item {
     fn from(value: VariableDeclaration) -> Self {
-        Item::VariableDeclaration(value)
+        Self::VariableDeclaration(value)
     }
 }
 
@@ -133,17 +122,17 @@ impl Expose {
     /// Check if `name` should be exposed as a function/mixin.
     pub fn allow_fun(&self, name: &Name) -> bool {
         match self {
-            Expose::All => true,
-            Expose::Show(show, _) => show.contains(name),
-            Expose::Hide(hide, _) => !hide.contains(name),
+            Self::All => true,
+            Self::Show(show, _) => show.contains(name),
+            Self::Hide(hide, _) => !hide.contains(name),
         }
     }
     /// Check if `name` should be exposed as a variable.
     pub fn allow_var(&self, name: &Name) -> bool {
         match self {
-            Expose::All => true,
-            Expose::Show(_, show) => show.contains(name),
-            Expose::Hide(_, hide) => !hide.contains(name),
+            Self::All => true,
+            Self::Show(_, show) => show.contains(name),
+            Self::Hide(_, hide) => !hide.contains(name),
         }
     }
 }
