@@ -1,6 +1,3 @@
-use super::Rational;
-use num_traits::{one, zero};
-
 /// A color defined by hue, whiteness, blackness, and alpha.
 ///
 /// All components are rational numbers.
@@ -8,12 +5,12 @@ use num_traits::{one, zero};
 /// The whiteness, blackness, and alpha are all in the zero to one
 /// range (inclusive), whith the additional invariant that whiteness +
 /// blackness will never be more than one.
-#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd)]
+#[derive(Clone, Debug, PartialEq, PartialOrd)]
 pub struct Hwba {
-    hue: Rational,
-    w: Rational,
-    b: Rational,
-    alpha: Rational,
+    hue: f64,
+    w: f64,
+    b: f64,
+    alpha: f64,
 }
 
 impl Hwba {
@@ -21,53 +18,43 @@ impl Hwba {
     ///
     /// Hue is modulo 360 degrees.  Other inputs will be clamped to
     /// their ranges.
-    pub fn new(
-        hue: Rational,
-        w: Rational,
-        b: Rational,
-        alpha: Rational,
-    ) -> Hwba {
-        let mut w = w.clamp(zero(), one());
-        let mut b = b.clamp(zero(), one());
+    pub fn new(hue: f64, w: f64, b: f64, alpha: f64) -> Self {
         let wbsum = w + b;
-        if w + b > one() {
-            w /= wbsum;
-            b /= wbsum;
-        }
-        Hwba {
-            hue,
-            w,
-            b,
-            alpha: alpha.clamp(zero(), one()),
-        }
+        let (w, b) = if wbsum > 1. {
+            (w / wbsum, b / wbsum)
+        } else {
+            (w, b)
+        };
+        let alpha = alpha.clamp(0., 1.);
+        Self { hue, w, b, alpha }
     }
 
     /// Get the hue of this color.
-    pub fn hue(&self) -> Rational {
+    pub fn hue(&self) -> f64 {
         self.hue
     }
     /// Get the whiteness of this color.
     ///
     /// Zero is no whiteness, one means this color is white.
-    pub fn whiteness(&self) -> Rational {
+    pub fn whiteness(&self) -> f64 {
         self.w
     }
     /// Get the black of this color.
     ///
     /// Zero is no blackness, one means this color is black.
-    pub fn blackness(&self) -> Rational {
+    pub fn blackness(&self) -> f64 {
         self.b
     }
     /// Get the alpha value of this color.
     ///
     /// Zero is fully transparent, one is fully opaque.
-    pub fn alpha(&self) -> Rational {
+    pub fn alpha(&self) -> f64 {
         self.alpha
     }
     /// Set the alpha value of this color.
     ///
     /// Zero is fully transparent, one is fully opaque.
-    pub fn set_alpha(&mut self, alpha: Rational) {
-        self.alpha = alpha.clamp(zero(), one());
+    pub fn set_alpha(&mut self, alpha: f64) {
+        self.alpha = alpha.clamp(0., 1.);
     }
 }
