@@ -1,10 +1,8 @@
 //! Color names from <https://www.w3.org/TR/css3-color/>
 #![allow(clippy::unreadable_literal)]
-use super::Rational;
 use crate::output::{Format, Formatted};
 use crate::value::Number;
 use lazy_static::lazy_static;
-use num_traits::{one, zero, One, Signed, Zero};
 use std::cmp::Ordering;
 use std::collections::BTreeMap;
 use std::fmt::{self, Display};
@@ -12,10 +10,10 @@ use std::fmt::{self, Display};
 /// A color defined by red, green, blue, and alpha components.
 #[derive(Clone, Debug)]
 pub struct Rgba {
-    red: Rational,
-    green: Rational,
-    blue: Rational,
-    alpha: Rational,
+    red: f64,
+    green: f64,
+    blue: f64,
+    alpha: f64,
     source: RgbFormat,
 }
 
@@ -34,120 +32,142 @@ pub enum RgbFormat {
 
 impl Rgba {
     /// Create a new rgba color.
-    pub fn new(
-        r: Rational,
-        g: Rational,
-        b: Rational,
-        a: Rational,
-        s: RgbFormat,
-    ) -> Self {
-        let ff = Rational::new(255, 1);
-        let one = Rational::one();
-        Rgba {
-            red: cap(r, &ff),
-            green: cap(g, &ff),
-            blue: cap(b, &ff),
-            alpha: cap(a, &one),
+    pub fn new(r: f64, g: f64, b: f64, a: f64, s: RgbFormat) -> Self {
+        let ff = 255.;
+        Self {
+            red: cap(r, ff),
+            green: cap(g, ff),
+            blue: cap(b, ff),
+            alpha: cap(a, 1.),
             source: s,
         }
     }
     /// Create a color from rgb byte values.
     pub fn from_rgb(r: u8, g: u8, b: u8) -> Self {
-        Rgba {
-            red: Rational::from_integer(r.into()),
-            green: Rational::from_integer(g.into()),
-            blue: Rational::from_integer(b.into()),
-            alpha: Rational::one(),
+        Self {
+            red: r.into(),
+            green: g.into(),
+            blue: b.into(),
+            alpha: 1.0,
             source: RgbFormat::LongHex,
         }
     }
     /// Create a color from rgba byte values.
     pub fn from_rgba(r: u8, g: u8, b: u8, a: u8) -> Self {
-        Rgba {
-            red: Rational::from_integer(r.into()),
-            green: Rational::from_integer(g.into()),
-            blue: Rational::from_integer(b.into()),
-            alpha: Rational::from_integer(a.into()) / 255,
+        Self {
+            red: r.into(),
+            green: g.into(),
+            blue: b.into(),
+            alpha: f64::from(a) / 255.,
             source: RgbFormat::LongHex,
         }
     }
 
+    fn is_opaque(&self) -> bool {
+        self.alpha >= 1.
+    }
     /// If this color is equal to a named color, get the name.
-    ///
-    /// Each component is rounded to its byte value before lookup.
     pub fn name(&self) -> Option<&'static str> {
-        if self.alpha >= Rational::one() {
-            let (r, g, b, _a) = self.to_bytes();
-            let c = u32::from_be_bytes([0, r, g, b]);
-            LOOKUP.v2n.get(&c).copied()
-        } else {
-            None
-        }
+        self.try_bytes()
+            .map(|(r, g, b)| u32::from_be_bytes([0, r, g, b]))
+            .and_then(|c| LOOKUP.v2n.get(&c).copied())
     }
     /// If `name` is a known color name, get the corresponding rgba value.
     pub fn from_name(name: &str) -> Option<Self> {
         let name = name.to_lowercase();
         let name: &str = &name;
         if name == "transparent" {
-            return Some(Self::new(
-                zero(),
-                zero(),
-                zero(),
-                zero(),
-                RgbFormat::Name,
-            ));
+            return Some(Self::new(0., 0., 0., 0., RgbFormat::Name));
         }
         LOOKUP.n2v.get(name).map(|n| {
             let [_, r, g, b] = n.to_be_bytes();
-            Self::new(
-                i64::from(r).into(),
-                i64::from(g).into(),
-                i64::from(b).into(),
-                one(),
-                RgbFormat::Name,
-            )
+            Self::new(r.into(), g.into(), b.into(), 1., RgbFormat::Name)
         })
     }
 
     /// Return true if all chanels are zero.
     pub fn all_zero(&self) -> bool {
-        self.alpha.is_zero()
-            && self.red.is_zero()
-            && self.green.is_zero()
-            && self.blue.is_zero()
+        self.alpha == 0.
+            && self.red == 0.
+            && self.green == 0.
+            && self.blue == 0.
+    }
+    pub(crate) fn is_integer(&self) -> bool {
+        near_integer(self.red)
+            && near_integer(self.green)
+            && near_integer(self.blue)
+            && self.is_opaque()
     }
     /// Get a (r, g, b, a) byte-value tuple for this color.
     pub fn to_bytes(&self) -> (u8, u8, u8, u8) {
-        fn byte(v: Rational) -> u8 {
-            v.round().to_integer() as u8
+        fn byte(v: f64) -> u8 {
+            v.round() as u8
+        }
+        fn fb(v: f64) -> u8 {
+            v.round() as u8
+        }
+        let a = self.alpha * 255.;
+        (byte(self.red), byte(self.green), byte(self.blue), fb(a))
+    }
+    /// Get a (r, g, b) byte-value tuple for this color.
+    ///
+    /// If the color is not opaque or not exactly equal to a byte
+    /// value, return None.
+    pub fn try_bytes(&self) -> Option<(u8, u8, u8)> {
+        if !self.is_opaque() {
+            return None;
+        }
+        fn byte(v: f64) -> Option<u8> {
+            if (v.round() - v).abs() < 1e-7 {
+                Some(v.round() as u8)
+            } else {
+                None
+            }
+        }
+        if let (Some(r), Some(g), Some(b)) =
+            (byte(self.red), byte(self.green), byte(self.blue))
+        {
+            Some((r, g, b))
+        } else {
+            None
         }
-        let a = self.alpha * 255;
-        (byte(self.red), byte(self.green), byte(self.blue), byte(a))
     }
     /// Get the red component.
-    pub fn red(&self) -> Rational {
+    pub fn red(&self) -> f64 {
         self.red
     }
     /// Get the green component.
-    pub fn green(&self) -> Rational {
+    pub fn green(&self) -> f64 {
         self.green
     }
     /// Get the blue component.
-    pub fn blue(&self) -> Rational {
+    pub fn blue(&self) -> f64 {
         self.blue
     }
     /// Get the alpha value of this color.
     ///
     /// Zero is fully transparent, one is fully opaque.
-    pub fn alpha(&self) -> Rational {
+    pub fn alpha(&self) -> f64 {
         self.alpha
     }
     /// Set the alpha value of this color.
     ///
     /// Zero is fully transparent, one is fully opaque.
-    pub fn set_alpha(&mut self, alpha: Rational) {
-        self.alpha = cap(alpha, &one());
+    pub fn set_alpha(&mut self, alpha: f64) {
+        self.alpha = alpha.clamp(0., 1.);
     }
+
+    pub(crate) fn invert(&self, weight: f64) -> Self {
+        let inv = |v: f64| -(v - 255.) * weight + v * (1. - weight);
+        Rgba::new(
+            inv(self.red()),
+            inv(self.green()),
+            inv(self.blue()),
+            self.alpha(),
+            self.source(),
+        )
+    }
+
     /// Get the source type of this color.
     pub(crate) fn source(&self) -> RgbFormat {
         self.source
@@ -165,7 +185,7 @@ impl Rgba {
 }
 
 impl PartialEq for Rgba {
-    fn eq(&self, other: &Rgba) -> bool {
+    fn eq(&self, other: &Self) -> bool {
         // ignores source!
         self.red == other.red
             && self.green == other.green
@@ -175,31 +195,37 @@ impl PartialEq for Rgba {
 }
 impl Eq for Rgba {}
 impl Ord for Rgba {
-    fn cmp(&self, other: &Rgba) -> Ordering {
+    fn cmp(&self, other: &Self) -> Ordering {
         // ignores source!
-        self.red
-            .cmp(&other.red)
-            .then_with(|| self.green.cmp(&other.green))
-            .then_with(|| self.blue.cmp(&other.blue))
-            .then_with(|| self.alpha.cmp(&other.alpha))
+        cmp_chan(self.red, other.red)
+            .then_with(|| cmp_chan(self.green, other.green))
+            .then_with(|| cmp_chan(self.blue, other.blue))
+            .then_with(|| cmp_chan(self.alpha, other.alpha))
     }
 }
 impl PartialOrd for Rgba {
-    fn partial_cmp(&self, other: &Rgba) -> Option<Ordering> {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
     }
 }
 
-fn cap(n: Rational, max: &Rational) -> Rational {
-    if n > *max {
-        *max
-    } else if n.is_negative() {
-        Rational::zero()
+fn cmp_chan(a: f64, b: f64) -> Ordering {
+    if (a - b).abs() < 1e-7 {
+        Ordering::Equal
     } else {
-        n
+        match (a.is_nan(), b.is_nan()) {
+            (true, true) => Ordering::Equal,
+            (true, false) => Ordering::Less,
+            (false, true) => Ordering::Greater,
+            (false, false) => a.partial_cmp(&b).unwrap(),
+        }
     }
 }
 
+fn cap(n: f64, max: f64) -> f64 {
+    f64::min(f64::max(0., n), max)
+}
+
 #[test]
 fn get_black() {
     assert_eq!(Rgba::from_rgb(0, 0, 0).name(), Some("black"))
@@ -233,7 +259,7 @@ impl Lookup {
             n2v.insert(n, v);
             v2n.entry(v).or_insert(n);
         }
-        Lookup { n2v, v2n }
+        Self { n2v, v2n }
     }
 }
 
@@ -390,13 +416,11 @@ lazy_static! {
     ]);
 }
 
-impl<'a> Display for Formatted<'a, Rgba> {
+impl Display for Formatted<'_, Rgba> {
     fn fmt(&self, out: &mut fmt::Formatter) -> fmt::Result {
         // The byte-version of alpha is not used here.
         let rgba = self.value;
-        let (r, g, b, _a) = rgba.to_bytes();
-        let a = self.value.alpha;
-        if a >= Rational::one() {
+        if let Some((r, g, b)) = rgba.try_bytes() {
             // E.g. #ff00cc can be written #f0c in css.
             // 0xff / 0x11 = 0xf.
             let short = r % 0x11 == 0 && g % 0x11 == 0 && b % 0x11 == 0;
@@ -439,20 +463,33 @@ impl<'a> Display for Formatted<'a, Rgba> {
             }
         } else if self.format.is_compressed() && rgba.all_zero() {
             write!(out, "transparent")
-        } else if self.format.is_compressed() {
-            // Note: libsass does not use the format for the alpha like this.
-            let a = Number::from(a);
-            write!(out, "rgba({},{},{},{})", r, g, b, a.format(self.format))
         } else {
-            let a = Number::from(a);
-            write!(
-                out,
-                "rgba({}, {}, {}, {})",
-                r,
-                g,
-                b,
-                a.format(self.format)
-            )
+            write_rgba(rgba, out, self.format)
         }
     }
 }
+
+fn write_rgba(
+    rgba: &Rgba,
+    out: &mut fmt::Formatter,
+    format: Format,
+) -> fmt::Result {
+    let r = Number::from(rgba.red);
+    let g = Number::from(rgba.green);
+    let b = Number::from(rgba.blue);
+    let r = r.format(format);
+    let g = g.format(format);
+    let b = b.format(format);
+    let sep = if format.is_compressed() { "," } else { ", " };
+    if rgba.is_opaque() {
+        write!(out, "rgb({r}{sep}{g}{sep}{b})")
+    } else {
+        let a = Number::from(rgba.alpha);
+        let a = a.format(format);
+        write!(out, "rgba({r}{sep}{g}{sep}{b}{sep}{a})")
+    }
+}
+
+fn near_integer(v: f64) -> bool {
+    (v - v.round()).abs() < 1e-7
+}
