@@ -11,10 +11,10 @@ mod unitset;
 
 pub use self::colors::{Color, Hsla, Hwba, RgbFormat, Rgba};
 pub use self::list_separator::ListSeparator;
-pub use self::number::{BadNumber, Number, Rational};
+pub use self::number::Number;
 pub use self::numeric::Numeric;
 pub use self::operator::{BadOp, Operator};
 pub use self::quotes::Quotes;
 pub use self::unit::{CssDimension, Dimension, Unit};
 pub use self::unitset::{CssDimensionSet, UnitSet};
-pub(crate) use range::{RangeError, ValueRange};
+pub(crate) use range::ValueRange;
