@@ -37,7 +37,7 @@ mod clamped {
         assert_eq!(
             runner().ok("a {b: hsl(0 100% 9999% / 0.5)}\n"),
             "a {\
-         \n  b: hsla(0, 100%, 100%, 0.5);\
+         \n  b: hsla(0, 100%, 9999%, 0.5);\
          \n}\n"
         );
     }
@@ -104,6 +104,32 @@ mod in_gamut {
         );
     }
 }
+mod missing {
+    #[allow(unused)]
+    use super::runner;
+
+    #[test]
+    #[ignore] // unexepected error
+    fn slash() {
+        assert_eq!(
+            runner().ok("a {b: hsl(180 60% 50% / none)}\n"),
+            "a {\
+         \n  b: hsl(180deg 60% 50% / none);\
+         \n}\n"
+        );
+    }
+    #[test]
+    #[ignore] // unexepected error
+    fn slash_list() {
+        assert_eq!(
+            runner().ok("@use \'sass:list\';\
+             \na {b: hsl(list.slash(180 60% 50%, none))}\n"),
+            "a {\
+         \n  b: hsl(180deg 60% 50% / none);\
+         \n}\n"
+        );
+    }
+}
 #[test]
 fn slash_list() {
     assert_eq!(
