@@ -9,11 +9,11 @@ fn runner() -> crate::TestRunner {
 fn test() {
     assert_eq!(
         runner().ok(
-            "@use \'sass:color\';\
+            "@use \"sass:color\";\
              \na {b: color.hwb($hue: 0, $whiteness: 30%, $blackness: 40%)}\n"
         ),
         "a {\
-         \n  b: #994d4d;\
+         \n  b: hsl(0, 33.3333333333%, 45%);\
          \n}\n"
     );
 }
