@@ -8,32 +8,38 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn too_few_args() {
     assert_eq!(
-        runner().err("a {a: inspect()}\n"),
+        runner().err(
+            "@use \"sass:meta\";\
+             \na {a: meta.inspect()}\n"
+        ),
         "Error: Missing argument $value.\
          \n  ,--> input.scss\
-         \n1 | a {a: inspect()}\
-         \n  |       ^^^^^^^^^ invocation\
+         \n2 | a {a: meta.inspect()}\
+         \n  |       ^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:meta\
          \n1 | @function inspect($value) {\
          \n  |           =============== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
 }
 #[test]
 fn too_many_args() {
     assert_eq!(
-        runner().err("a {a: inspect(1, 2)}\n"),
+        runner().err(
+            "@use \"sass:meta\";\
+             \na {a: meta.inspect(1, 2)}\n"
+        ),
         "Error: Only 1 argument allowed, but 2 were passed.\
          \n  ,--> input.scss\
-         \n1 | a {a: inspect(1, 2)}\
-         \n  |       ^^^^^^^^^^^^^ invocation\
+         \n2 | a {a: meta.inspect(1, 2)}\
+         \n  |       ^^^^^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:meta\
          \n1 | @function inspect($value) {\
          \n  |           =============== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
 }
