@@ -9,12 +9,13 @@ fn runner() -> crate::TestRunner {
 fn unit() {
     assert_eq!(
         runner().ok(
-            "// We explicitly don\'t test the inspect format for complex units. Their format\
+            "@use \"sass:meta\";\
+             \n// We explicitly don\'t test the inspect format for complex units. Their format\
              \n// isn\'t guaranteed by the spec, since they can\'t be written literally in Sass.\
-             \n$result: inspect(50px);\
+             \n$result: meta.inspect(50px);\
              \na {\
              \n  value: $result;\
-             \n  type: type-of($result);\
+             \n  type: meta.type-of($result);\
              \n}\n"
         ),
         "a {\
@@ -26,10 +27,11 @@ fn unit() {
 #[test]
 fn unitless() {
     assert_eq!(
-        runner().ok("$result: inspect(123.456);\
+        runner().ok("@use \"sass:meta\";\
+             \n$result: meta.inspect(123.456);\
              \na {\
              \n  value: $result;\
-             \n  type: type-of($result);\
+             \n  type: meta.type-of($result);\
              \n}\n"),
         "a {\
          \n  value: 123.456;\
