@@ -9,15 +9,17 @@ fn runner() -> crate::TestRunner {
 fn quoted() {
     assert_eq!(
         runner().ok(
-            "$result: inspect(\"foo\");\
+            "@use \"sass:meta\";\
+             \n@use \"sass:string\";\
+             \n$result: meta.inspect(\"foo\");\
              \na {\
              \n  value: $result;\
-             \n  type: type-of($result);\n\
+             \n  type: meta.type-of($result);\n\
              \n  // inspect() should always return an unquoted string, so when it\'s passed a\
              \n  // quoted string its return value should contain quote characters. We check\
              \n  // the length to verify that the quotes are included, since there\'s no\
              \n  // built-in way to check whether a string is quoted.\
-             \n  length: str-length($result);\
+             \n  length: string.length($result);\
              \n}\n"
         ),
         "a {\
@@ -30,10 +32,11 @@ fn quoted() {
 #[test]
 fn unquoted() {
     assert_eq!(
-        runner().ok("$result: inspect(foo);\
+        runner().ok("@use \"sass:meta\";\
+             \n$result: meta.inspect(foo);\
              \na {\
              \n  value: $result;\
-             \n  type: type-of($result);\
+             \n  type: meta.type-of($result);\
              \n}\n"),
         "a {\
          \n  value: foo;\
