@@ -8,8 +8,9 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn arglist() {
     assert_eq!(
-        runner().ok("@function type-of-arglist($args...) {\
-             \n  @return type-of($args);\
+        runner().ok("@use \"sass:meta\";\
+             \n@function type-of-arglist($args...) {\
+             \n  @return meta.type-of($args);\
              \n}\n\
              \na {b: type-of-arglist()}\n"),
         "a {\
@@ -24,7 +25,8 @@ mod boolean {
     #[test]
     fn test_false() {
         assert_eq!(
-            runner().ok("a {b: type-of(false)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(false)}\n"),
             "a {\
          \n  b: bool;\
          \n}\n"
@@ -33,7 +35,8 @@ mod boolean {
     #[test]
     fn test_true() {
         assert_eq!(
-            runner().ok("a {b: type-of(true)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(true)}\n"),
             "a {\
          \n  b: bool;\
          \n}\n"
@@ -51,7 +54,8 @@ mod calculation {
         #[test]
         fn calc() {
             assert_eq!(
-                runner().ok("a {b: type-of(calc(var(--c)))}\n"),
+                runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(calc(var(--c)))}\n"),
                 "a {\
          \n  b: calculation;\
          \n}\n"
@@ -60,7 +64,8 @@ mod calculation {
         #[test]
         fn clamp() {
             assert_eq!(
-                runner().ok("a {b: type-of(clamp(1%, 1px, 2px))}\n"),
+                runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(clamp(1%, 1px, 2px))}\n"),
                 "a {\
          \n  b: calculation;\
          \n}\n"
@@ -70,7 +75,8 @@ mod calculation {
     #[test]
     fn simplified() {
         assert_eq!(
-            runner().ok("a {b: type-of(calc(1px))}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(calc(1px))}\n"),
             "a {\
          \n  b: number;\
          \n}\n"
@@ -80,7 +86,8 @@ mod calculation {
 #[test]
 fn color() {
     assert_eq!(
-        runner().ok("a {b: type-of(red)}\n"),
+        runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(red)}\n"),
         "a {\
          \n  b: color;\
          \n}\n"
@@ -93,40 +100,49 @@ mod error {
     #[test]
     fn too_few_args() {
         assert_eq!(
-            runner().err("a {b: type-of()}\n"),
+            runner().err(
+                "@use \"sass:meta\";\
+             \na {b: meta.type-of()}\n"
+            ),
             "Error: Missing argument $value.\
          \n  ,--> input.scss\
-         \n1 | a {b: type-of()}\
-         \n  |       ^^^^^^^^^ invocation\
+         \n2 | a {b: meta.type-of()}\
+         \n  |       ^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:meta\
          \n1 | @function type-of($value) {\
          \n  |           =============== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
         );
     }
     #[test]
     fn too_many_args() {
         assert_eq!(
-            runner().err("a {b: type-of(1, 2)}\n"),
+            runner().err(
+                "@use \"sass:meta\";\
+             \na {b: meta.type-of(1, 2)}\n"
+            ),
             "Error: Only 1 argument allowed, but 2 were passed.\
          \n  ,--> input.scss\
-         \n1 | a {b: type-of(1, 2)}\
-         \n  |       ^^^^^^^^^^^^^ invocation\
+         \n2 | a {b: meta.type-of(1, 2)}\
+         \n  |       ^^^^^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:meta\
          \n1 | @function type-of($value) {\
          \n  |           =============== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
         );
     }
 }
 #[test]
 fn function() {
     assert_eq!(
-        runner().ok("a {b: type-of(get-function(\"type-of\"))}\n"),
+        runner().ok(
+            "@use \"sass:meta\";\
+             \na {b: meta.type-of(meta.get-function(\"type-of\", $module: \"meta\"))}\n"
+        ),
         "a {\
          \n  b: function;\
          \n}\n"
@@ -139,7 +155,8 @@ mod list {
     #[test]
     fn empty() {
         assert_eq!(
-            runner().ok("a {b: type-of(())}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(())}\n"),
             "a {\
          \n  b: list;\
          \n}\n"
@@ -148,7 +165,8 @@ mod list {
     #[test]
     fn non_empty() {
         assert_eq!(
-            runner().ok("a {b: type-of(1 2 3)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(1 2 3)}\n"),
             "a {\
          \n  b: list;\
          \n}\n"
@@ -162,7 +180,9 @@ mod map {
     #[test]
     fn empty() {
         assert_eq!(
-            runner().ok("a {b: type-of(map-remove((c: d), c))}\n"),
+            runner().ok("@use \"sass:map\";\
+             \n@use \"sass:meta\";\
+             \na {b: meta.type-of(map.remove((c: d), c))}\n"),
             "a {\
          \n  b: map;\
          \n}\n"
@@ -171,7 +191,8 @@ mod map {
     #[test]
     fn non_empty() {
         assert_eq!(
-            runner().ok("a {b: type-of((c: d))}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of((c: d))}\n"),
             "a {\
          \n  b: map;\
          \n}\n"
@@ -187,7 +208,7 @@ mod mixin {
     fn builtin() {
         assert_eq!(
             runner().ok("@use \"sass:meta\";\
-             \na {b: type-of(meta.get-mixin(load-css, meta))}\n"),
+             \na {b: meta.type-of(meta.get-mixin(load-css, meta))}\n"),
             "a {\
          \n  b: mixin;\
          \n}\n"
@@ -199,7 +220,7 @@ mod mixin {
         assert_eq!(
             runner().ok("@use \"sass:meta\";\
              \n@mixin a() {}\
-             \na {b: type-of(meta.get-mixin(a))}\n"),
+             \na {b: meta.type-of(meta.get-mixin(a))}\n"),
             "a {\
          \n  b: mixin;\
          \n}\n"
@@ -209,7 +230,8 @@ mod mixin {
 #[test]
 fn named() {
     assert_eq!(
-        runner().ok("a {b: type-of($value: c)}\n"),
+        runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of($value: c)}\n"),
         "a {\
          \n  b: string;\
          \n}\n"
@@ -218,7 +240,8 @@ fn named() {
 #[test]
 fn null() {
     assert_eq!(
-        runner().ok("a {b: type-of(null)}\n"),
+        runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(null)}\n"),
         "a {\
          \n  b: null;\
          \n}\n"
@@ -231,7 +254,8 @@ mod number {
     #[test]
     fn unit() {
         assert_eq!(
-            runner().ok("a {b: type-of(1.5px * 3.4em)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(1.5px * 3.4em)}\n"),
             "a {\
          \n  b: number;\
          \n}\n"
@@ -240,7 +264,8 @@ mod number {
     #[test]
     fn unitless() {
         assert_eq!(
-            runner().ok("a {b: type-of(1)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(1)}\n"),
             "a {\
          \n  b: number;\
          \n}\n"
@@ -254,7 +279,8 @@ mod string {
     #[test]
     fn quoted() {
         assert_eq!(
-            runner().ok("a {b: type-of(\"c\")}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(\"c\")}\n"),
             "a {\
          \n  b: string;\
          \n}\n"
@@ -263,7 +289,8 @@ mod string {
     #[test]
     fn unquoted() {
         assert_eq!(
-            runner().ok("a {b: type-of(c)}\n"),
+            runner().ok("@use \"sass:meta\";\
+             \na {b: meta.type-of(c)}\n"),
             "a {\
          \n  b: string;\
          \n}\n"
