@@ -8,7 +8,8 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn equal() {
     assert_eq!(
-        runner().ok("a {b: is-superselector(\"#c\", \"#c\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\"#c\", \"#c\")}\n"),
         "a {\
          \n  b: true;\
          \n}\n"
@@ -17,7 +18,8 @@ fn equal() {
 #[test]
 fn unequal() {
     assert_eq!(
-        runner().ok("a {b: is-superselector(\"#c\", \"#d\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\"#c\", \"#d\")}\n"),
         "a {\
          \n  b: false;\
          \n}\n"
