@@ -13,7 +13,8 @@ mod prefix {
     fn subset() {
         assert_eq!(
         runner().ok(
-            "a {b: is-superselector(\":-pfx-any(c d.i, e j f)\", \"c d, e f, g h\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\":-pfx-any(c d.i, e j f)\", \"c d, e f, g h\")}\n"
         ),
         "a {\
          \n  b: false;\
@@ -25,7 +26,8 @@ mod prefix {
     fn superset() {
         assert_eq!(
         runner().ok(
-            "a {b: is-superselector(\":-pfx-any(c d, e f, g h)\", \"c d.i, e j f\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\":-pfx-any(c d, e f, g h)\", \"c d.i, e j f\")}\n"
         ),
         "a {\
          \n  b: true;\
@@ -37,7 +39,8 @@ mod prefix {
 fn subset() {
     assert_eq!(
         runner().ok(
-            "a {b: is-superselector(\":any(c d.i, e j f)\", \"c d, e f, g h\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\":any(c d.i, e j f)\", \"c d, e f, g h\")}\n"
         ),
         "a {\
          \n  b: false;\
@@ -49,7 +52,8 @@ fn subset() {
 fn superset() {
     assert_eq!(
         runner().ok(
-            "a {b: is-superselector(\":any(c d, e f, g h)\", \"c d.i, e j f\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.is-superselector(\":any(c d, e f, g h)\", \"c d.i, e j f\")}\n"
         ),
         "a {\
          \n  b: true;\
