@@ -8,7 +8,8 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn complex() {
     assert_eq!(
-        runner().ok("a {b: selector-replace(\"c d\", \"d\", \"e f\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c d\", \"d\", \"e f\")}\n"),
         "a {\
          \n  b: c e f, e c f;\
          \n}\n"
@@ -17,7 +18,8 @@ fn complex() {
 #[test]
 fn compound() {
     assert_eq!(
-        runner().ok("a {b: selector-replace(\"c.d\", \"c\", \"e\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c.d\", \"c\", \"e\")}\n"),
         "a {\
          \n  b: e.d;\
          \n}\n"
@@ -38,37 +40,41 @@ mod error {
             #[test]
             fn list() {
                 assert_eq!(
-                    runner()
-                        .err("a {b: selector-replace(\"c\", d e, \"f\")}\n"),
+                    runner().err(
+                        "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", d e, \"f\")}\n"
+                    ),
                     "Error: Can\'t extend complex selector d e.\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", d e, \"f\")}\
+         \n2 | a {b: selector.replace(\"c\", d e, \"f\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
                 );
             }
             #[test]
             fn string() {
                 assert_eq!(
                     runner().err(
-                        "a {b: selector-replace(\"c\", \"d e\", \"f\")}\n"
+                        "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d e\", \"f\")}\n"
                     ),
                     "Error: Can\'t extend complex selector d e.\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"d e\", \"f\")}\
+         \n2 | a {b: selector.replace(\"c\", \"d e\", \"f\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
                 );
             }
         }
         #[test]
-        #[ignore] // wrong error
         fn invalid() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"c\", \"[d\", \"e\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"[d\", \"e\")}\n"
+                ),
                 "Error: $original: expected more input.\
          \n  ,\
          \n1 | [d\
@@ -76,17 +82,19 @@ mod error {
          \n  \'\
          \n  - 1:3  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"[d\", \"e\")}\
+         \n2 | a {b: selector.replace(\"c\", \"[d\", \"e\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn parent() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"c\", \"&\", \"d\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"&\", \"d\")}\n"
+                ),
                 "Error: $original: Parent selectors aren\'t allowed here.\
          \n  ,\
          \n1 | &\
@@ -94,25 +102,26 @@ mod error {
          \n  \'\
          \n  - 1:1  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"&\", \"d\")}\
+         \n2 | a {b: selector.replace(\"c\", \"&\", \"d\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn test_type() {
             assert_eq!(
         runner().err(
-            "a {b: selector-replace(\"c\", 1, \"d\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", 1, \"d\")}\n"
         ),
         "Error: $original: 1 is not a valid selector: it must be a string,\
          \na list of strings, or a list of lists of strings.\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", 1, \"d\")}\
+         \n2 | a {b: selector.replace(\"c\", 1, \"d\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
         }
     }
@@ -121,11 +130,12 @@ mod error {
         use super::runner;
 
         #[test]
-        #[ignore] // wrong error
         fn invalid() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"c\", \"d\", \"[e\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\", \"[e\")}\n"
+                ),
                 "Error: $replacement: expected more input.\
          \n  ,\
          \n1 | [e\
@@ -133,17 +143,19 @@ mod error {
          \n  \'\
          \n  - 1:3  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"d\", \"[e\")}\
+         \n2 | a {b: selector.replace(\"c\", \"d\", \"[e\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn parent() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"c\", \"d\", \"&\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\", \"&\")}\n"
+                ),
                 "Error: $replacement: Parent selectors aren\'t allowed here.\
          \n  ,\
          \n1 | &\
@@ -151,25 +163,26 @@ mod error {
          \n  \'\
          \n  - 1:1  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"d\", \"&\")}\
+         \n2 | a {b: selector.replace(\"c\", \"d\", \"&\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn test_type() {
             assert_eq!(
         runner().err(
-            "a {b: selector-replace(\"c\", \"d\", 1)}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\", 1)}\n"
         ),
         "Error: $replacement: 1 is not a valid selector: it must be a string,\
          \na list of strings, or a list of lists of strings.\
          \n  ,\
-         \n1 | a {b: selector-replace(\"c\", \"d\", 1)}\
+         \n2 | a {b: selector.replace(\"c\", \"d\", 1)}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
         }
     }
@@ -178,11 +191,12 @@ mod error {
         use super::runner;
 
         #[test]
-        #[ignore] // wrong error
         fn invalid() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"[c\", \"d\", \"e\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"[c\", \"d\", \"e\")}\n"
+                ),
                 "Error: $selector: expected more input.\
          \n  ,\
          \n1 | [c\
@@ -190,17 +204,19 @@ mod error {
          \n  \'\
          \n  - 1:3  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"[c\", \"d\", \"e\")}\
+         \n2 | a {b: selector.replace(\"[c\", \"d\", \"e\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn parent() {
             assert_eq!(
-                runner()
-                    .err("a {b: selector-replace(\"&\", \"c\", \"d\")}\n"),
+                runner().err(
+                    "@use \"sass:selector\";\
+             \na {b: selector.replace(\"&\", \"c\", \"d\")}\n"
+                ),
                 "Error: $selector: Parent selectors aren\'t allowed here.\
          \n  ,\
          \n1 | &\
@@ -208,25 +224,26 @@ mod error {
          \n  \'\
          \n  - 1:1  root stylesheet\
          \n  ,\
-         \n1 | a {b: selector-replace(\"&\", \"c\", \"d\")}\
+         \n2 | a {b: selector.replace(\"&\", \"c\", \"d\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
             );
         }
         #[test]
         fn test_type() {
             assert_eq!(
         runner().err(
-            "a {b: selector-replace(1, \"c\", \"d\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace(1, \"c\", \"d\")}\n"
         ),
         "Error: $selector: 1 is not a valid selector: it must be a string,\
          \na list of strings, or a list of lists of strings.\
          \n  ,\
-         \n1 | a {b: selector-replace(1, \"c\", \"d\")}\
+         \n2 | a {b: selector.replace(1, \"c\", \"d\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
         }
     }
@@ -234,38 +251,55 @@ mod error {
     fn too_few_args() {
         assert_eq!(
         runner().err(
-            "a {b: selector-replace(\"c\", \"d\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\")}\n"
         ),
         "Error: Missing argument $replacement.\
          \n  ,--> input.scss\
-         \n1 | a {b: selector-replace(\"c\", \"d\")}\
+         \n2 | a {b: selector.replace(\"c\", \"d\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:selector\
          \n1 | @function replace($selector, $original, $replacement) {\
          \n  |           =========================================== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
     }
     #[test]
     fn too_many_args() {
         assert_eq!(
         runner().err(
-            "a {b: selector-replace(\"c\", \"d\", \"e\", \"f\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\", \"e\", \"f\")}\n"
         ),
         "Error: Only 3 arguments allowed, but 4 were passed.\
          \n  ,--> input.scss\
-         \n1 | a {b: selector-replace(\"c\", \"d\", \"e\", \"f\")}\
+         \n2 | a {b: selector.replace(\"c\", \"d\", \"e\", \"f\")}\
          \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ invocation\
          \n  \'\
          \n  ,--> sass:selector\
          \n1 | @function replace($selector, $original, $replacement) {\
          \n  |           =========================================== declaration\
          \n  \'\
-         \n  input.scss 1:7  root stylesheet",
+         \n  input.scss 2:7  root stylesheet",
     );
     }
+    #[test]
+    fn wrong_name() {
+        assert_eq!(
+            runner().err(
+                "@use \"sass:selector\";\
+             \na {b: selector.selector-replace(c, c, d)}\n"
+            ),
+            "Error: Undefined function.\
+         \n  ,\
+         \n2 | a {b: selector.selector-replace(c, c, d)}\
+         \n  |       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\
+         \n  \'\
+         \n  input.scss 2:7  root stylesheet",
+        );
+    }
 }
 mod format {
     #[allow(unused)]
@@ -282,9 +316,8 @@ mod format {
             #[test]
             fn compound() {
                 assert_eq!(
-                    runner().ok(
-                        "a {b: selector-replace(\"c.d\", \"c.d\", \".e\")}\n"
-                    ),
+                    runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c.d\", \"c.d\", \".e\")}\n"),
                     "a {\
          \n  b: .e;\
          \n}\n"
@@ -293,24 +326,24 @@ mod format {
             #[test]
             fn list() {
                 assert_eq!(
-        runner().ok(
-            "a {b: selector-replace(\"c.d\", \"c, .d\", \".e\")}\n"
-        ),
-        "a {\
+                    runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c.d\", \"c, .d\", \".e\")}\n"),
+                    "a {\
          \n  b: .e;\
          \n}\n"
-    );
+                );
             }
             #[test]
             fn list_of_compound() {
                 assert_eq!(
-        runner().ok(
-            "a {b: selector-replace(\"c.d.e.f\", \"c.d, .e.f\", \".g\")}\n"
-        ),
-        "a {\
+                    runner().ok(
+                        "@use \"sass:selector\";\
+             \na {b: selector.replace(\"c.d.e.f\", \"c.d, .e.f\", \".g\")}\n"
+                    ),
+                    "a {\
          \n  b: .g;\
          \n}\n"
-    );
+                );
             }
         }
         mod non_string {
@@ -320,20 +353,18 @@ mod format {
             #[test]
             fn extendee() {
                 assert_eq!(
-        runner().ok(
-            "a {b: selector-replace(\"c.d\", (c, \".d\"), \".e\")}\n"
-        ),
-        "a {\
+                    runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c.d\", (c, \".d\"), \".e\")}\n"),
+                    "a {\
          \n  b: .e;\
          \n}\n"
-    );
+                );
             }
             #[test]
             fn extender() {
                 assert_eq!(
-                    runner().ok(
-                        "a {b: selector-replace(\"c\", \"c\", (d, e f))}\n"
-                    ),
+                    runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"c\", (d, e f))}\n"),
                     "a {\
          \n  b: d, e f;\
          \n}\n"
@@ -342,9 +373,8 @@ mod format {
             #[test]
             fn selector() {
                 assert_eq!(
-                    runner().ok(
-                        "a {b: selector-replace((c, d c), \"c\", \"e\")}\n"
-                    ),
+                    runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace((c, d c), \"c\", \"e\")}\n"),
                     "a {\
          \n  b: e, d e;\
          \n}\n"
@@ -355,13 +385,12 @@ mod format {
     #[test]
     fn output() {
         assert_eq!(
-            runner().ok(
-                "$result: selector-replace(\"c d, e f\", \"g\", \"g\");\
+            runner().ok("@use \"sass:selector\";\
+             \n$result: selector.replace(\"c d, e f\", \"g\", \"g\");\
              \na {\
              \n  result: $result;\
              \n  structure: $result == (\"c\" \"d\", \"e\" \"f\");\
-             \n}\n"
-            ),
+             \n}\n"),
             "a {\
          \n  result: c d, e f;\
          \n  structure: true;\
@@ -373,7 +402,8 @@ mod format {
 fn named() {
     assert_eq!(
         runner().ok(
-            "a {b: selector-replace($selector: \"c.d\", $original: \"c\", $replacement: \"e\")}\n"
+            "@use \"sass:selector\";\
+             \na {b: selector.replace($selector: \"c.d\", $original: \"c\", $replacement: \"e\")}\n"
         ),
         "a {\
          \n  b: e.d;\
@@ -383,7 +413,8 @@ fn named() {
 #[test]
 fn no_op() {
     assert_eq!(
-        runner().ok("a {b: selector-replace(\"c\", \"d\", \"e\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"d\", \"e\")}\n"),
         "a {\
          \n  b: c;\
          \n}\n"
@@ -392,7 +423,8 @@ fn no_op() {
 #[test]
 fn partial_no_op() {
     assert_eq!(
-        runner().ok("a {b: selector-replace(\"c, d\", \"d\", \"e\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c, d\", \"d\", \"e\")}\n"),
         "a {\
          \n  b: c, e;\
          \n}\n"
@@ -405,8 +437,8 @@ mod selector_pseudo {
     #[test]
     fn is() {
         assert_eq!(
-            runner()
-                .ok("a {b: selector-replace(\":is(c)\", \"c\", \"d\")}\n"),
+            runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\":is(c)\", \"c\", \"d\")}\n"),
             "a {\
          \n  b: :is(d);\
          \n}\n"
@@ -415,9 +447,8 @@ mod selector_pseudo {
     #[test]
     fn matches() {
         assert_eq!(
-            runner().ok(
-                "a {b: selector-replace(\":matches(c)\", \"c\", \"d\")}\n"
-            ),
+            runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\":matches(c)\", \"c\", \"d\")}\n"),
             "a {\
          \n  b: :matches(d);\
          \n}\n"
@@ -426,8 +457,8 @@ mod selector_pseudo {
     #[test]
     fn not() {
         assert_eq!(
-            runner()
-                .ok("a {b: selector-replace(\":not(c)\", \"c\", \"d\")}\n"),
+            runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\":not(c)\", \"c\", \"d\")}\n"),
             "a {\
          \n  b: :not(d);\
          \n}\n"
@@ -436,8 +467,8 @@ mod selector_pseudo {
     #[test]
     fn test_where() {
         assert_eq!(
-            runner()
-                .ok("a {b: selector-replace(\":where(c)\", \"c\", \"d\")}\n"),
+            runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\":where(c)\", \"c\", \"d\")}\n"),
             "a {\
          \n  b: :where(d);\
          \n}\n"
@@ -447,7 +478,8 @@ mod selector_pseudo {
 #[test]
 fn simple() {
     assert_eq!(
-        runner().ok("a {b: selector-replace(\"c\", \"c\", \"d\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.replace(\"c\", \"c\", \"d\")}\n"),
         "a {\
          \n  b: d;\
          \n}\n"
