@@ -8,7 +8,8 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("a {b: selector-unify(\"c\", \"#d\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.unify(\"c\", \"#d\")}\n"),
         "a {\
          \n  b: c#d;\
          \n}\n"
