@@ -8,7 +8,9 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn different() {
     assert_eq!(
-        runner().ok("a {b: inspect(selector-unify(\"#c\", \"#d\"))}\n"),
+        runner().ok("@use \"sass:meta\";\
+             \n@use \"sass:selector\";\
+             \na {b: meta.inspect(selector.unify(\"#c\", \"#d\"))}\n"),
         "a {\
          \n  b: null;\
          \n}\n"
@@ -17,7 +19,8 @@ fn different() {
 #[test]
 fn same() {
     assert_eq!(
-        runner().ok("a {b: selector-unify(\"#c\", \"#c\")}\n"),
+        runner().ok("@use \"sass:selector\";\
+             \na {b: selector.unify(\"#c\", \"#c\")}\n"),
         "a {\
          \n  b: #c;\
          \n}\n"
