@@ -20,43 +20,41 @@ fn runner() -> crate::TestRunner {
 fn built_in() {
     let runner = runner().with_cwd("built_in");
     assert_eq!(
-        runner.err("@import \'plain\'"),
+        runner.err("@use \'plain\'"),
         "Error: This function isn\'t allowed in plain CSS.\
          \n  ,\
          \n2 |   x: index(1 2 3, 1);\
          \n  |      ^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  plain.css 2:6   @import\
-         \n  input.scss 1:9  root stylesheet",
+         \n  plain.css 2:6   @use\
+         \n  input.scss 1:1  root stylesheet",
     );
 }
 #[test]
-#[ignore] // wrong error
 fn keyword_arguments() {
     let runner = runner().with_cwd("keyword_arguments");
     assert_eq!(
-        runner.err("@import \'plain\'"),
+        runner.err("@use \'plain\'"),
         "Error: Sass variables aren\'t allowed in plain CSS.\
          \n  ,\
          \n2 |   x: hsl(0, 100%, $lightness: 50%);\
          \n  |                   ^^^^^^^^^^\
          \n  \'\
-         \n  plain.css 2:19  @import\
-         \n  input.scss 1:9  root stylesheet",
+         \n  plain.css 2:19  @use\
+         \n  input.scss 1:1  root stylesheet",
     );
 }
 #[test]
-#[ignore] // missing error
 fn variable_arguments() {
     let runner = runner().with_cwd("variable_arguments");
     assert_eq!(
-        runner.err("@import \'plain\'"),
+        runner.err("@use \'plain\'"),
         "Error: expected \")\".\
          \n  ,\
          \n2 |   x: hsl(0, 100%, 50%...);\
          \n  |                      ^\
          \n  \'\
-         \n  plain.css 2:22  @import\
-         \n  input.scss 1:9  root stylesheet",
+         \n  plain.css 2:22  @use\
+         \n  input.scss 1:1  root stylesheet",
     );
 }
