@@ -5,7 +5,7 @@ fn runner() -> crate::TestRunner {
     super::runner()
         .with_cwd("variable_exists")
         .mock_file("_midstream.scss", "@forward \"upstream\" with ($a: configured);\n")
-        .mock_file("_upstream.scss", "$before-declaration: variable-exists(a);\n$a: original !default;\nb {\n  before-declaration: $before-declaration;\n  after-declaration: variable-exists(a);\n}\n")
+        .mock_file("_upstream.scss", "@use \"sass:meta\";\n$before-declaration: meta.variable-exists(a);\n$a: original !default;\nb {\n  before-declaration: $before-declaration;\n  after-declaration: meta.variable-exists(a);\n}\n")
 }
 
 #[test]
