@@ -7,6 +7,8 @@ fn runner() -> crate::TestRunner {
 
 mod at_root;
 
+mod each;
+
 // Ignoring "extend", not expected to work yet.
 
 mod test_for;
@@ -19,6 +21,8 @@ mod test_if;
 
 mod import;
 
+mod mixin;
+
 mod test_use;
 
 mod warn;
