@@ -4,7 +4,7 @@
 fn runner() -> crate::TestRunner {
     super::runner()
         .with_cwd("variable_exists")
-        .mock_file("_other.scss", "$before-declaration: variable-exists(a);\n$a: original !default;\nb {\n  before-declaration: $before-declaration;\n  after-declaration: variable-exists(a);\n}\n")
+        .mock_file("_other.scss", "@use \"sass:meta\";\n$before-declaration: meta.variable-exists(a);\n$a: original !default;\nb {\n  before-declaration: $before-declaration;\n  after-declaration: meta.variable-exists(a);\n}\n")
 }
 
 #[test]
