@@ -15,7 +15,14 @@ fn test() {
         runner().err(
             "@import \"include.scss\";"
         ),
-        "Error: Top-level selectors may not contain the parent selector \"&\".\
+        "DEPRECATION WARNING [import]: Sass @import rules are deprecated and will be removed in Dart Sass 3.0.0.\n\
+         \nMore info and automated migrator: https://sass-lang.com/d/import\n\
+         \n  ,\
+         \n1 | @import \"include.scss\";\
+         \n  |         ^^^^^^^^^^^^^^\
+         \n  \'\
+         \n    input.scss 1:9  root stylesheet\n\
+         \nError: Top-level selectors may not contain the parent selector \"&\".\
          \n  ,\
          \n2 |   &post {\
          \n  |   ^^^^^\
