@@ -636,105 +636,105 @@ fn test() {
          \nfoo {\
          \n  c-1: rgb(0, 0, 0);\
          \n  c0: rgb(0, 0, 0);\
-         \n  c1: rgb(0, 0, 3);\
-         \n  c2: rgb(0, 0, 5);\
-         \n  c3: rgb(0, 0, 8);\
-         \n  c4: rgb(0, 0, 10);\
-         \n  c5: rgb(0, 0, 13);\
-         \n  c6: rgb(0, 0, 15);\
-         \n  c7: rgb(0, 0, 18);\
-         \n  c8: rgb(0, 0, 20);\
-         \n  c9: rgb(0, 0, 23);\
-         \n  c10: rgb(0, 0, 26);\
-         \n  c11: rgb(0, 0, 28);\
-         \n  c12: rgb(0, 0, 31);\
-         \n  c13: rgb(0, 0, 33);\
-         \n  c14: rgb(0, 0, 36);\
-         \n  c15: rgb(0, 0, 38);\
-         \n  c16: rgb(0, 0, 41);\
-         \n  c17: rgb(0, 0, 43);\
-         \n  c18: rgb(0, 0, 46);\
-         \n  c19: rgb(0, 0, 48);\
+         \n  c1: rgb(0, 0, 2.55);\
+         \n  c2: rgb(0, 0, 5.1);\
+         \n  c3: rgb(0, 0, 7.65);\
+         \n  c4: rgb(0, 0, 10.2);\
+         \n  c5: rgb(0, 0, 12.75);\
+         \n  c6: rgb(0, 0, 15.3);\
+         \n  c7: rgb(0, 0, 17.85);\
+         \n  c8: rgb(0, 0, 20.4);\
+         \n  c9: rgb(0, 0, 22.95);\
+         \n  c10: rgb(0, 0, 25.5);\
+         \n  c11: rgb(0, 0, 28.05);\
+         \n  c12: rgb(0, 0, 30.6);\
+         \n  c13: rgb(0, 0, 33.15);\
+         \n  c14: rgb(0, 0, 35.7);\
+         \n  c15: rgb(0, 0, 38.25);\
+         \n  c16: rgb(0, 0, 40.8);\
+         \n  c17: rgb(0, 0, 43.35);\
+         \n  c18: rgb(0, 0, 45.9);\
+         \n  c19: rgb(0, 0, 48.45);\
          \n  c20: rgb(0, 0, 51);\
-         \n  c21: rgb(0, 0, 54);\
-         \n  c22: rgb(0, 0, 56);\
-         \n  c23: rgb(0, 0, 59);\
-         \n  c24: rgb(0, 0, 61);\
-         \n  c25: rgb(0, 0, 64);\
-         \n  c26: rgb(0, 0, 66);\
-         \n  c27: rgb(0, 0, 69);\
-         \n  c28: rgb(0, 0, 71);\
-         \n  c29: rgb(0, 0, 74);\
-         \n  c30: rgb(0, 0, 77);\
-         \n  c31: rgb(0, 0, 79);\
-         \n  c32: rgb(0, 0, 82);\
-         \n  c33: rgb(0, 0, 84);\
-         \n  c34: rgb(0, 0, 87);\
-         \n  c35: rgb(0, 0, 89);\
-         \n  c36: rgb(0, 0, 92);\
-         \n  c37: rgb(0, 0, 94);\
-         \n  c38: rgb(0, 0, 97);\
-         \n  c39: rgb(0, 0, 99);\
+         \n  c21: rgb(0, 0, 53.55);\
+         \n  c22: rgb(0, 0, 56.1);\
+         \n  c23: rgb(0, 0, 58.65);\
+         \n  c24: rgb(0, 0, 61.2);\
+         \n  c25: rgb(0, 0, 63.75);\
+         \n  c26: rgb(0, 0, 66.3);\
+         \n  c27: rgb(0, 0, 68.85);\
+         \n  c28: rgb(0, 0, 71.4);\
+         \n  c29: rgb(0, 0, 73.95);\
+         \n  c30: rgb(0, 0, 76.5);\
+         \n  c31: rgb(0, 0, 79.05);\
+         \n  c32: rgb(0, 0, 81.6);\
+         \n  c33: rgb(0, 0, 84.15);\
+         \n  c34: rgb(0, 0, 86.7);\
+         \n  c35: rgb(0, 0, 89.25);\
+         \n  c36: rgb(0, 0, 91.8);\
+         \n  c37: rgb(0, 0, 94.35);\
+         \n  c38: rgb(0, 0, 96.9);\
+         \n  c39: rgb(0, 0, 99.45);\
          \n  c40: rgb(0, 0, 102);\
-         \n  c41: rgb(0, 0, 105);\
-         \n  c42: rgb(0, 0, 107);\
-         \n  c43: rgb(0, 0, 110);\
-         \n  c44: rgb(0, 0, 112);\
-         \n  c45: rgb(0, 0, 115);\
-         \n  c46: rgb(0, 0, 117);\
-         \n  c47: rgb(0, 0, 120);\
-         \n  c48: rgb(0, 0, 122);\
-         \n  c49: rgb(0, 0, 125);\
-         \n  c50: rgb(0, 0, 128);\
-         \n  c51: rgb(0, 0, 130);\
-         \n  c52: rgb(0, 0, 133);\
-         \n  c53: rgb(0, 0, 135);\
-         \n  c54: rgb(0, 0, 138);\
-         \n  c55: rgb(0, 0, 140);\
-         \n  c56: rgb(0, 0, 143);\
-         \n  c57: rgb(0, 0, 145);\
-         \n  c58: rgb(0, 0, 148);\
-         \n  c59: rgb(0, 0, 150);\
+         \n  c41: rgb(0, 0, 104.55);\
+         \n  c42: rgb(0, 0, 107.1);\
+         \n  c43: rgb(0, 0, 109.65);\
+         \n  c44: rgb(0, 0, 112.2);\
+         \n  c45: rgb(0, 0, 114.75);\
+         \n  c46: rgb(0, 0, 117.3);\
+         \n  c47: rgb(0, 0, 119.85);\
+         \n  c48: rgb(0, 0, 122.4);\
+         \n  c49: rgb(0, 0, 124.95);\
+         \n  c50: rgb(0, 0, 127.5);\
+         \n  c51: rgb(0, 0, 130.05);\
+         \n  c52: rgb(0, 0, 132.6);\
+         \n  c53: rgb(0, 0, 135.15);\
+         \n  c54: rgb(0, 0, 137.7);\
+         \n  c55: rgb(0, 0, 140.25);\
+         \n  c56: rgb(0, 0, 142.8);\
+         \n  c57: rgb(0, 0, 145.35);\
+         \n  c58: rgb(0, 0, 147.9);\
+         \n  c59: rgb(0, 0, 150.45);\
          \n  c60: rgb(0, 0, 153);\
-         \n  c61: rgb(0, 0, 156);\
-         \n  c62: rgb(0, 0, 158);\
-         \n  c63: rgb(0, 0, 161);\
-         \n  c64: rgb(0, 0, 163);\
-         \n  c65: rgb(0, 0, 166);\
-         \n  c66: rgb(0, 0, 168);\
-         \n  c67: rgb(0, 0, 171);\
-         \n  c68: rgb(0, 0, 173);\
-         \n  c69: rgb(0, 0, 176);\
-         \n  c70: rgb(0, 0, 179);\
-         \n  c71: rgb(0, 0, 181);\
-         \n  c72: rgb(0, 0, 184);\
-         \n  c73: rgb(0, 0, 186);\
-         \n  c74: rgb(0, 0, 189);\
-         \n  c75: rgb(0, 0, 191);\
-         \n  c76: rgb(0, 0, 194);\
-         \n  c77: rgb(0, 0, 196);\
-         \n  c78: rgb(0, 0, 199);\
-         \n  c79: rgb(0, 0, 201);\
+         \n  c61: rgb(0, 0, 155.55);\
+         \n  c62: rgb(0, 0, 158.1);\
+         \n  c63: rgb(0, 0, 160.65);\
+         \n  c64: rgb(0, 0, 163.2);\
+         \n  c65: rgb(0, 0, 165.75);\
+         \n  c66: rgb(0, 0, 168.3);\
+         \n  c67: rgb(0, 0, 170.85);\
+         \n  c68: rgb(0, 0, 173.4);\
+         \n  c69: rgb(0, 0, 175.95);\
+         \n  c70: rgb(0, 0, 178.5);\
+         \n  c71: rgb(0, 0, 181.05);\
+         \n  c72: rgb(0, 0, 183.6);\
+         \n  c73: rgb(0, 0, 186.15);\
+         \n  c74: rgb(0, 0, 188.7);\
+         \n  c75: rgb(0, 0, 191.25);\
+         \n  c76: rgb(0, 0, 193.8);\
+         \n  c77: rgb(0, 0, 196.35);\
+         \n  c78: rgb(0, 0, 198.9);\
+         \n  c79: rgb(0, 0, 201.45);\
          \n  c80: rgb(0, 0, 204);\
-         \n  c81: rgb(0, 0, 207);\
-         \n  c82: rgb(0, 0, 209);\
-         \n  c83: rgb(0, 0, 212);\
-         \n  c84: rgb(0, 0, 214);\
-         \n  c85: rgb(0, 0, 217);\
-         \n  c86: rgb(0, 0, 219);\
-         \n  c87: rgb(0, 0, 222);\
-         \n  c88: rgb(0, 0, 224);\
-         \n  c89: rgb(0, 0, 227);\
-         \n  c90: rgb(0, 0, 230);\
-         \n  c91: rgb(0, 0, 232);\
-         \n  c92: rgb(0, 0, 235);\
-         \n  c93: rgb(0, 0, 237);\
-         \n  c94: rgb(0, 0, 240);\
-         \n  c95: rgb(0, 0, 242);\
-         \n  c96: rgb(0, 0, 245);\
-         \n  c97: rgb(0, 0, 247);\
-         \n  c98: rgb(0, 0, 250);\
-         \n  c99: rgb(0, 0, 252);\
+         \n  c81: rgb(0, 0, 206.55);\
+         \n  c82: rgb(0, 0, 209.1);\
+         \n  c83: rgb(0, 0, 211.65);\
+         \n  c84: rgb(0, 0, 214.2);\
+         \n  c85: rgb(0, 0, 216.75);\
+         \n  c86: rgb(0, 0, 219.3);\
+         \n  c87: rgb(0, 0, 221.85);\
+         \n  c88: rgb(0, 0, 224.4);\
+         \n  c89: rgb(0, 0, 226.95);\
+         \n  c90: rgb(0, 0, 229.5);\
+         \n  c91: rgb(0, 0, 232.05);\
+         \n  c92: rgb(0, 0, 234.6);\
+         \n  c93: rgb(0, 0, 237.15);\
+         \n  c94: rgb(0, 0, 239.7);\
+         \n  c95: rgb(0, 0, 242.25);\
+         \n  c96: rgb(0, 0, 244.8);\
+         \n  c97: rgb(0, 0, 247.35);\
+         \n  c98: rgb(0, 0, 249.9);\
+         \n  c99: rgb(0, 0, 252.45);\
          \n  c100: rgb(0, 0, 255);\
          \n  c101: rgb(0, 0, 255);\
          \n}\n"
