@@ -636,105 +636,105 @@ fn test() {
          \nfoo {\
          \n  c-1: rgb(0, 0, 0);\
          \n  c0: rgb(0, 0, 0);\
-         \n  c1: rgb(0, 3, 0);\
-         \n  c2: rgb(0, 5, 0);\
-         \n  c3: rgb(0, 8, 0);\
-         \n  c4: rgb(0, 10, 0);\
-         \n  c5: rgb(0, 13, 0);\
-         \n  c6: rgb(0, 15, 0);\
-         \n  c7: rgb(0, 18, 0);\
-         \n  c8: rgb(0, 20, 0);\
-         \n  c9: rgb(0, 23, 0);\
-         \n  c10: rgb(0, 26, 0);\
-         \n  c11: rgb(0, 28, 0);\
-         \n  c12: rgb(0, 31, 0);\
-         \n  c13: rgb(0, 33, 0);\
-         \n  c14: rgb(0, 36, 0);\
-         \n  c15: rgb(0, 38, 0);\
-         \n  c16: rgb(0, 41, 0);\
-         \n  c17: rgb(0, 43, 0);\
-         \n  c18: rgb(0, 46, 0);\
-         \n  c19: rgb(0, 48, 0);\
+         \n  c1: rgb(0, 2.55, 0);\
+         \n  c2: rgb(0, 5.1, 0);\
+         \n  c3: rgb(0, 7.65, 0);\
+         \n  c4: rgb(0, 10.2, 0);\
+         \n  c5: rgb(0, 12.75, 0);\
+         \n  c6: rgb(0, 15.3, 0);\
+         \n  c7: rgb(0, 17.85, 0);\
+         \n  c8: rgb(0, 20.4, 0);\
+         \n  c9: rgb(0, 22.95, 0);\
+         \n  c10: rgb(0, 25.5, 0);\
+         \n  c11: rgb(0, 28.05, 0);\
+         \n  c12: rgb(0, 30.6, 0);\
+         \n  c13: rgb(0, 33.15, 0);\
+         \n  c14: rgb(0, 35.7, 0);\
+         \n  c15: rgb(0, 38.25, 0);\
+         \n  c16: rgb(0, 40.8, 0);\
+         \n  c17: rgb(0, 43.35, 0);\
+         \n  c18: rgb(0, 45.9, 0);\
+         \n  c19: rgb(0, 48.45, 0);\
          \n  c20: rgb(0, 51, 0);\
-         \n  c21: rgb(0, 54, 0);\
-         \n  c22: rgb(0, 56, 0);\
-         \n  c23: rgb(0, 59, 0);\
-         \n  c24: rgb(0, 61, 0);\
-         \n  c25: rgb(0, 64, 0);\
-         \n  c26: rgb(0, 66, 0);\
-         \n  c27: rgb(0, 69, 0);\
-         \n  c28: rgb(0, 71, 0);\
-         \n  c29: rgb(0, 74, 0);\
-         \n  c30: rgb(0, 77, 0);\
-         \n  c31: rgb(0, 79, 0);\
-         \n  c32: rgb(0, 82, 0);\
-         \n  c33: rgb(0, 84, 0);\
-         \n  c34: rgb(0, 87, 0);\
-         \n  c35: rgb(0, 89, 0);\
-         \n  c36: rgb(0, 92, 0);\
-         \n  c37: rgb(0, 94, 0);\
-         \n  c38: rgb(0, 97, 0);\
-         \n  c39: rgb(0, 99, 0);\
+         \n  c21: rgb(0, 53.55, 0);\
+         \n  c22: rgb(0, 56.1, 0);\
+         \n  c23: rgb(0, 58.65, 0);\
+         \n  c24: rgb(0, 61.2, 0);\
+         \n  c25: rgb(0, 63.75, 0);\
+         \n  c26: rgb(0, 66.3, 0);\
+         \n  c27: rgb(0, 68.85, 0);\
+         \n  c28: rgb(0, 71.4, 0);\
+         \n  c29: rgb(0, 73.95, 0);\
+         \n  c30: rgb(0, 76.5, 0);\
+         \n  c31: rgb(0, 79.05, 0);\
+         \n  c32: rgb(0, 81.6, 0);\
+         \n  c33: rgb(0, 84.15, 0);\
+         \n  c34: rgb(0, 86.7, 0);\
+         \n  c35: rgb(0, 89.25, 0);\
+         \n  c36: rgb(0, 91.8, 0);\
+         \n  c37: rgb(0, 94.35, 0);\
+         \n  c38: rgb(0, 96.9, 0);\
+         \n  c39: rgb(0, 99.45, 0);\
          \n  c40: rgb(0, 102, 0);\
-         \n  c41: rgb(0, 105, 0);\
-         \n  c42: rgb(0, 107, 0);\
-         \n  c43: rgb(0, 110, 0);\
-         \n  c44: rgb(0, 112, 0);\
-         \n  c45: rgb(0, 115, 0);\
-         \n  c46: rgb(0, 117, 0);\
-         \n  c47: rgb(0, 120, 0);\
-         \n  c48: rgb(0, 122, 0);\
-         \n  c49: rgb(0, 125, 0);\
-         \n  c50: rgb(0, 128, 0);\
-         \n  c51: rgb(0, 130, 0);\
-         \n  c52: rgb(0, 133, 0);\
-         \n  c53: rgb(0, 135, 0);\
-         \n  c54: rgb(0, 138, 0);\
-         \n  c55: rgb(0, 140, 0);\
-         \n  c56: rgb(0, 143, 0);\
-         \n  c57: rgb(0, 145, 0);\
-         \n  c58: rgb(0, 148, 0);\
-         \n  c59: rgb(0, 150, 0);\
+         \n  c41: rgb(0, 104.55, 0);\
+         \n  c42: rgb(0, 107.1, 0);\
+         \n  c43: rgb(0, 109.65, 0);\
+         \n  c44: rgb(0, 112.2, 0);\
+         \n  c45: rgb(0, 114.75, 0);\
+         \n  c46: rgb(0, 117.3, 0);\
+         \n  c47: rgb(0, 119.85, 0);\
+         \n  c48: rgb(0, 122.4, 0);\
+         \n  c49: rgb(0, 124.95, 0);\
+         \n  c50: rgb(0, 127.5, 0);\
+         \n  c51: rgb(0, 130.05, 0);\
+         \n  c52: rgb(0, 132.6, 0);\
+         \n  c53: rgb(0, 135.15, 0);\
+         \n  c54: rgb(0, 137.7, 0);\
+         \n  c55: rgb(0, 140.25, 0);\
+         \n  c56: rgb(0, 142.8, 0);\
+         \n  c57: rgb(0, 145.35, 0);\
+         \n  c58: rgb(0, 147.9, 0);\
+         \n  c59: rgb(0, 150.45, 0);\
          \n  c60: rgb(0, 153, 0);\
-         \n  c61: rgb(0, 156, 0);\
-         \n  c62: rgb(0, 158, 0);\
-         \n  c63: rgb(0, 161, 0);\
-         \n  c64: rgb(0, 163, 0);\
-         \n  c65: rgb(0, 166, 0);\
-         \n  c66: rgb(0, 168, 0);\
-         \n  c67: rgb(0, 171, 0);\
-         \n  c68: rgb(0, 173, 0);\
-         \n  c69: rgb(0, 176, 0);\
-         \n  c70: rgb(0, 179, 0);\
-         \n  c71: rgb(0, 181, 0);\
-         \n  c72: rgb(0, 184, 0);\
-         \n  c73: rgb(0, 186, 0);\
-         \n  c74: rgb(0, 189, 0);\
-         \n  c75: rgb(0, 191, 0);\
-         \n  c76: rgb(0, 194, 0);\
-         \n  c77: rgb(0, 196, 0);\
-         \n  c78: rgb(0, 199, 0);\
-         \n  c79: rgb(0, 201, 0);\
+         \n  c61: rgb(0, 155.55, 0);\
+         \n  c62: rgb(0, 158.1, 0);\
+         \n  c63: rgb(0, 160.65, 0);\
+         \n  c64: rgb(0, 163.2, 0);\
+         \n  c65: rgb(0, 165.75, 0);\
+         \n  c66: rgb(0, 168.3, 0);\
+         \n  c67: rgb(0, 170.85, 0);\
+         \n  c68: rgb(0, 173.4, 0);\
+         \n  c69: rgb(0, 175.95, 0);\
+         \n  c70: rgb(0, 178.5, 0);\
+         \n  c71: rgb(0, 181.05, 0);\
+         \n  c72: rgb(0, 183.6, 0);\
+         \n  c73: rgb(0, 186.15, 0);\
+         \n  c74: rgb(0, 188.7, 0);\
+         \n  c75: rgb(0, 191.25, 0);\
+         \n  c76: rgb(0, 193.8, 0);\
+         \n  c77: rgb(0, 196.35, 0);\
+         \n  c78: rgb(0, 198.9, 0);\
+         \n  c79: rgb(0, 201.45, 0);\
          \n  c80: rgb(0, 204, 0);\
-         \n  c81: rgb(0, 207, 0);\
-         \n  c82: rgb(0, 209, 0);\
-         \n  c83: rgb(0, 212, 0);\
-         \n  c84: rgb(0, 214, 0);\
-         \n  c85: rgb(0, 217, 0);\
-         \n  c86: rgb(0, 219, 0);\
-         \n  c87: rgb(0, 222, 0);\
-         \n  c88: rgb(0, 224, 0);\
-         \n  c89: rgb(0, 227, 0);\
-         \n  c90: rgb(0, 230, 0);\
-         \n  c91: rgb(0, 232, 0);\
-         \n  c92: rgb(0, 235, 0);\
-         \n  c93: rgb(0, 237, 0);\
-         \n  c94: rgb(0, 240, 0);\
-         \n  c95: rgb(0, 242, 0);\
-         \n  c96: rgb(0, 245, 0);\
-         \n  c97: rgb(0, 247, 0);\
-         \n  c98: rgb(0, 250, 0);\
-         \n  c99: rgb(0, 252, 0);\
+         \n  c81: rgb(0, 206.55, 0);\
+         \n  c82: rgb(0, 209.1, 0);\
+         \n  c83: rgb(0, 211.65, 0);\
+         \n  c84: rgb(0, 214.2, 0);\
+         \n  c85: rgb(0, 216.75, 0);\
+         \n  c86: rgb(0, 219.3, 0);\
+         \n  c87: rgb(0, 221.85, 0);\
+         \n  c88: rgb(0, 224.4, 0);\
+         \n  c89: rgb(0, 226.95, 0);\
+         \n  c90: rgb(0, 229.5, 0);\
+         \n  c91: rgb(0, 232.05, 0);\
+         \n  c92: rgb(0, 234.6, 0);\
+         \n  c93: rgb(0, 237.15, 0);\
+         \n  c94: rgb(0, 239.7, 0);\
+         \n  c95: rgb(0, 242.25, 0);\
+         \n  c96: rgb(0, 244.8, 0);\
+         \n  c97: rgb(0, 247.35, 0);\
+         \n  c98: rgb(0, 249.9, 0);\
+         \n  c99: rgb(0, 252.45, 0);\
          \n  c100: rgb(0, 255, 0);\
          \n  c101: rgb(0, 255, 0);\
          \n}\n"
