@@ -636,105 +636,105 @@ fn test() {
          \nfoo {\
          \n  c-1: rgb(0, 0, 0);\
          \n  c0: rgb(0, 0, 0);\
-         \n  c1: rgb(3, 0, 0);\
-         \n  c2: rgb(5, 0, 0);\
-         \n  c3: rgb(8, 0, 0);\
-         \n  c4: rgb(10, 0, 0);\
-         \n  c5: rgb(13, 0, 0);\
-         \n  c6: rgb(15, 0, 0);\
-         \n  c7: rgb(18, 0, 0);\
-         \n  c8: rgb(20, 0, 0);\
-         \n  c9: rgb(23, 0, 0);\
-         \n  c10: rgb(26, 0, 0);\
-         \n  c11: rgb(28, 0, 0);\
-         \n  c12: rgb(31, 0, 0);\
-         \n  c13: rgb(33, 0, 0);\
-         \n  c14: rgb(36, 0, 0);\
-         \n  c15: rgb(38, 0, 0);\
-         \n  c16: rgb(41, 0, 0);\
-         \n  c17: rgb(43, 0, 0);\
-         \n  c18: rgb(46, 0, 0);\
-         \n  c19: rgb(48, 0, 0);\
+         \n  c1: rgb(2.55, 0, 0);\
+         \n  c2: rgb(5.1, 0, 0);\
+         \n  c3: rgb(7.65, 0, 0);\
+         \n  c4: rgb(10.2, 0, 0);\
+         \n  c5: rgb(12.75, 0, 0);\
+         \n  c6: rgb(15.3, 0, 0);\
+         \n  c7: rgb(17.85, 0, 0);\
+         \n  c8: rgb(20.4, 0, 0);\
+         \n  c9: rgb(22.95, 0, 0);\
+         \n  c10: rgb(25.5, 0, 0);\
+         \n  c11: rgb(28.05, 0, 0);\
+         \n  c12: rgb(30.6, 0, 0);\
+         \n  c13: rgb(33.15, 0, 0);\
+         \n  c14: rgb(35.7, 0, 0);\
+         \n  c15: rgb(38.25, 0, 0);\
+         \n  c16: rgb(40.8, 0, 0);\
+         \n  c17: rgb(43.35, 0, 0);\
+         \n  c18: rgb(45.9, 0, 0);\
+         \n  c19: rgb(48.45, 0, 0);\
          \n  c20: rgb(51, 0, 0);\
-         \n  c21: rgb(54, 0, 0);\
-         \n  c22: rgb(56, 0, 0);\
-         \n  c23: rgb(59, 0, 0);\
-         \n  c24: rgb(61, 0, 0);\
-         \n  c25: rgb(64, 0, 0);\
-         \n  c26: rgb(66, 0, 0);\
-         \n  c27: rgb(69, 0, 0);\
-         \n  c28: rgb(71, 0, 0);\
-         \n  c29: rgb(74, 0, 0);\
-         \n  c30: rgb(77, 0, 0);\
-         \n  c31: rgb(79, 0, 0);\
-         \n  c32: rgb(82, 0, 0);\
-         \n  c33: rgb(84, 0, 0);\
-         \n  c34: rgb(87, 0, 0);\
-         \n  c35: rgb(89, 0, 0);\
-         \n  c36: rgb(92, 0, 0);\
-         \n  c37: rgb(94, 0, 0);\
-         \n  c38: rgb(97, 0, 0);\
-         \n  c39: rgb(99, 0, 0);\
+         \n  c21: rgb(53.55, 0, 0);\
+         \n  c22: rgb(56.1, 0, 0);\
+         \n  c23: rgb(58.65, 0, 0);\
+         \n  c24: rgb(61.2, 0, 0);\
+         \n  c25: rgb(63.75, 0, 0);\
+         \n  c26: rgb(66.3, 0, 0);\
+         \n  c27: rgb(68.85, 0, 0);\
+         \n  c28: rgb(71.4, 0, 0);\
+         \n  c29: rgb(73.95, 0, 0);\
+         \n  c30: rgb(76.5, 0, 0);\
+         \n  c31: rgb(79.05, 0, 0);\
+         \n  c32: rgb(81.6, 0, 0);\
+         \n  c33: rgb(84.15, 0, 0);\
+         \n  c34: rgb(86.7, 0, 0);\
+         \n  c35: rgb(89.25, 0, 0);\
+         \n  c36: rgb(91.8, 0, 0);\
+         \n  c37: rgb(94.35, 0, 0);\
+         \n  c38: rgb(96.9, 0, 0);\
+         \n  c39: rgb(99.45, 0, 0);\
          \n  c40: rgb(102, 0, 0);\
-         \n  c41: rgb(105, 0, 0);\
-         \n  c42: rgb(107, 0, 0);\
-         \n  c43: rgb(110, 0, 0);\
-         \n  c44: rgb(112, 0, 0);\
-         \n  c45: rgb(115, 0, 0);\
-         \n  c46: rgb(117, 0, 0);\
-         \n  c47: rgb(120, 0, 0);\
-         \n  c48: rgb(122, 0, 0);\
-         \n  c49: rgb(125, 0, 0);\
-         \n  c50: rgb(128, 0, 0);\
-         \n  c51: rgb(130, 0, 0);\
-         \n  c52: rgb(133, 0, 0);\
-         \n  c53: rgb(135, 0, 0);\
-         \n  c54: rgb(138, 0, 0);\
-         \n  c55: rgb(140, 0, 0);\
-         \n  c56: rgb(143, 0, 0);\
-         \n  c57: rgb(145, 0, 0);\
-         \n  c58: rgb(148, 0, 0);\
-         \n  c59: rgb(150, 0, 0);\
+         \n  c41: rgb(104.55, 0, 0);\
+         \n  c42: rgb(107.1, 0, 0);\
+         \n  c43: rgb(109.65, 0, 0);\
+         \n  c44: rgb(112.2, 0, 0);\
+         \n  c45: rgb(114.75, 0, 0);\
+         \n  c46: rgb(117.3, 0, 0);\
+         \n  c47: rgb(119.85, 0, 0);\
+         \n  c48: rgb(122.4, 0, 0);\
+         \n  c49: rgb(124.95, 0, 0);\
+         \n  c50: rgb(127.5, 0, 0);\
+         \n  c51: rgb(130.05, 0, 0);\
+         \n  c52: rgb(132.6, 0, 0);\
+         \n  c53: rgb(135.15, 0, 0);\
+         \n  c54: rgb(137.7, 0, 0);\
+         \n  c55: rgb(140.25, 0, 0);\
+         \n  c56: rgb(142.8, 0, 0);\
+         \n  c57: rgb(145.35, 0, 0);\
+         \n  c58: rgb(147.9, 0, 0);\
+         \n  c59: rgb(150.45, 0, 0);\
          \n  c60: rgb(153, 0, 0);\
-         \n  c61: rgb(156, 0, 0);\
-         \n  c62: rgb(158, 0, 0);\
-         \n  c63: rgb(161, 0, 0);\
-         \n  c64: rgb(163, 0, 0);\
-         \n  c65: rgb(166, 0, 0);\
-         \n  c66: rgb(168, 0, 0);\
-         \n  c67: rgb(171, 0, 0);\
-         \n  c68: rgb(173, 0, 0);\
-         \n  c69: rgb(176, 0, 0);\
-         \n  c70: rgb(179, 0, 0);\
-         \n  c71: rgb(181, 0, 0);\
-         \n  c72: rgb(184, 0, 0);\
-         \n  c73: rgb(186, 0, 0);\
-         \n  c74: rgb(189, 0, 0);\
-         \n  c75: rgb(191, 0, 0);\
-         \n  c76: rgb(194, 0, 0);\
-         \n  c77: rgb(196, 0, 0);\
-         \n  c78: rgb(199, 0, 0);\
-         \n  c79: rgb(201, 0, 0);\
+         \n  c61: rgb(155.55, 0, 0);\
+         \n  c62: rgb(158.1, 0, 0);\
+         \n  c63: rgb(160.65, 0, 0);\
+         \n  c64: rgb(163.2, 0, 0);\
+         \n  c65: rgb(165.75, 0, 0);\
+         \n  c66: rgb(168.3, 0, 0);\
+         \n  c67: rgb(170.85, 0, 0);\
+         \n  c68: rgb(173.4, 0, 0);\
+         \n  c69: rgb(175.95, 0, 0);\
+         \n  c70: rgb(178.5, 0, 0);\
+         \n  c71: rgb(181.05, 0, 0);\
+         \n  c72: rgb(183.6, 0, 0);\
+         \n  c73: rgb(186.15, 0, 0);\
+         \n  c74: rgb(188.7, 0, 0);\
+         \n  c75: rgb(191.25, 0, 0);\
+         \n  c76: rgb(193.8, 0, 0);\
+         \n  c77: rgb(196.35, 0, 0);\
+         \n  c78: rgb(198.9, 0, 0);\
+         \n  c79: rgb(201.45, 0, 0);\
          \n  c80: rgb(204, 0, 0);\
-         \n  c81: rgb(207, 0, 0);\
-         \n  c82: rgb(209, 0, 0);\
-         \n  c83: rgb(212, 0, 0);\
-         \n  c84: rgb(214, 0, 0);\
-         \n  c85: rgb(217, 0, 0);\
-         \n  c86: rgb(219, 0, 0);\
-         \n  c87: rgb(222, 0, 0);\
-         \n  c88: rgb(224, 0, 0);\
-         \n  c89: rgb(227, 0, 0);\
-         \n  c90: rgb(230, 0, 0);\
-         \n  c91: rgb(232, 0, 0);\
-         \n  c92: rgb(235, 0, 0);\
-         \n  c93: rgb(237, 0, 0);\
-         \n  c94: rgb(240, 0, 0);\
-         \n  c95: rgb(242, 0, 0);\
-         \n  c96: rgb(245, 0, 0);\
-         \n  c97: rgb(247, 0, 0);\
-         \n  c98: rgb(250, 0, 0);\
-         \n  c99: rgb(252, 0, 0);\
+         \n  c81: rgb(206.55, 0, 0);\
+         \n  c82: rgb(209.1, 0, 0);\
+         \n  c83: rgb(211.65, 0, 0);\
+         \n  c84: rgb(214.2, 0, 0);\
+         \n  c85: rgb(216.75, 0, 0);\
+         \n  c86: rgb(219.3, 0, 0);\
+         \n  c87: rgb(221.85, 0, 0);\
+         \n  c88: rgb(224.4, 0, 0);\
+         \n  c89: rgb(226.95, 0, 0);\
+         \n  c90: rgb(229.5, 0, 0);\
+         \n  c91: rgb(232.05, 0, 0);\
+         \n  c92: rgb(234.6, 0, 0);\
+         \n  c93: rgb(237.15, 0, 0);\
+         \n  c94: rgb(239.7, 0, 0);\
+         \n  c95: rgb(242.25, 0, 0);\
+         \n  c96: rgb(244.8, 0, 0);\
+         \n  c97: rgb(247.35, 0, 0);\
+         \n  c98: rgb(249.9, 0, 0);\
+         \n  c99: rgb(252.45, 0, 0);\
          \n  c100: rgb(255, 0, 0);\
          \n  c101: rgb(255, 0, 0);\
          \n}\n"
