@@ -8,12 +8,13 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$foo: ((4, 5), 6, (7 8) 9);\n\
+        runner().ok("@use \"sass:meta\";\n\
+             \n$foo: ((4, 5), 6, (7 8) 9);\n\
              \nbar {\
              \n  a: $foo;\
              \n  f: 1 2 3 + $foo;\
              \n  b: 1, 2, 3 + (2 ($foo));\
-             \n  x: inspect($foo);\
+             \n  x: meta.inspect($foo);\
              \n}\n"),
         "bar {\
          \n  a: 4, 5, 6, 7 8 9;\
