@@ -8,15 +8,18 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("@function noop($string) {\
+        runner().ok(
+            "@use \"sass:string\";\
+             \n@function noop($string) {\
              \n  @return $string;\
              \n}\n\
              \n.foo {\
-             \n  upper: to-upper-case(\'f\') + str-slice(\'foo\', 2);\
-             \n  lower: to-lower-case(\'f\') + str-slice(\'foo\', 2);\
-             \n  user-upper: to-upper-case(\'f\') + noop(\'oo\');\
-             \n  user-lower: to-lower-case(\'f\') + noop(\'oo\');\
-             \n}\n"),
+             \n  upper: string.to-upper-case(\'f\') + string.slice(\'foo\', 2);\
+             \n  lower: string.to-lower-case(\'f\') + string.slice(\'foo\', 2);\
+             \n  user-upper: string.to-upper-case(\'f\') + noop(\'oo\');\
+             \n  user-lower: string.to-lower-case(\'f\') + noop(\'oo\');\
+             \n}\n"
+        ),
         ".foo {\
          \n  upper: \"Foo\";\
          \n  lower: \"foo\";\
