@@ -8,10 +8,11 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok(".container {\
+        runner().ok("@use \"sass:color\";\
+             \n.container {\
              \n  @for $i from 1 through 3 {\
              \n    @at-root .box-#{$i} {\
-             \n      color: darken(red,($i * 5));\
+             \n      color: color.adjust(red,$lightness: -($i * 5%));\
              \n    }\
              \n  }\n\
              \n // Control\
@@ -20,13 +21,13 @@ fn test() {
              \n  }\
              \n}\n"),
         ".box-1 {\
-         \n  color: #e60000;\
+         \n  color: rgb(229.5, 0, 0);\
          \n}\
          \n.box-2 {\
          \n  color: #cc0000;\
          \n}\
          \n.box-3 {\
-         \n  color: #b30000;\
+         \n  color: rgb(178.5, 0, 0);\
          \n}\
          \n.outside-child {\
          \n  background-color: blue;\
