@@ -8,13 +8,16 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().err("@debug(selector-nest(\"foo\", null));\n"),
+        runner().err(
+            "@use \"sass:selector\";\
+             \n@debug(selector.nest(\"foo\", null));\n"
+        ),
         "Error: null is not a valid selector: it must be a string,\
          \na list of strings, or a list of lists of strings.\
          \n  ,\
-         \n1 | @debug(selector-nest(\"foo\", null));\
+         \n2 | @debug(selector.nest(\"foo\", null));\
          \n  |        ^^^^^^^^^^^^^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:8  root stylesheet",
+         \n  input.scss 2:8  root stylesheet",
     );
 }
