@@ -9,16 +9,17 @@ fn runner() -> crate::TestRunner {
 fn test() {
     assert_eq!(
         runner().err(
-            "div.colors {\
-             \n  background: grayscale(red);\
+            "@use \"sass:color\";\
+             \ndiv.colors {\
+             \n  background: color.grayscale(red);\
              \n  background: saturate(red);\
-             \n  background: invert(red);\
-             \n  background: alpha(red);\
-             \n  color: grayscale(#369);\
+             \n  background: color.invert(red);\
+             \n  background: color.alpha(red);\
+             \n  color: color.grayscale(#369);\
              \n  color: saturate(#369);\
-             \n  color: saturate(#369, 20%);\
-             \n  color: invert(#369);\
-             \n  color: alpha(#369);\
+             \n  color: color.adjust(#369, $saturation: 20%);\
+             \n  color: color.invert(#369);\
+             \n  color: color.alpha(#369);\
              \n}\n\
              \ndiv.numbers {\
              \n  filter: grayscale(30%);\
@@ -31,9 +32,9 @@ fn test() {
         ),
         "Error: $amount: red is not a number.\
          \n  ,\
-         \n3 |   background: saturate(red);\
+         \n4 |   background: saturate(red);\
          \n  |               ^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 3:15  root stylesheet",
+         \n  input.scss 4:15  root stylesheet",
     );
 }
