@@ -17,8 +17,8 @@ fn test() {
         "Error: Top-level selectors may not contain the parent selector \"&\".\
          \n  ,\
          \n1 | foo & {\
-         \n  | ^^^^^^\
+         \n  |     ^\
          \n  \'\
-         \n  input.scss 1:1  root stylesheet",
+         \n  input.scss 1:5  root stylesheet",
     );
 }
