@@ -8,9 +8,10 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$score: (item-height: 1.12em);\
+        runner().ok("@use \"sass:map\";\
+             \n$score: (item-height: 1.12em);\
              \n.test {\
-             \n    background-position: 0 -#{map-get($score, item-height)};\
+             \n    background-position: 0 -#{map.get($score, item-height)};\
              \n}\n\n"),
         ".test {\
          \n  background-position: 0 -1.12em;\
