@@ -8,18 +8,19 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok(".test .nest {\
-             \n  length: length(&);\
+        runner().ok("@use \"sass:list\";\
+             \n.test .nest {\
+             \n  length: list.length(&);\
              \n  @each $list in & {\
              \n    list: $list;\
-             \n    length: length($list);\
+             \n    length: list.length($list);\
              \n  }\
              \n}\n\
              \n.test, .other {\
-             \n  length: length(&);\
+             \n  length: list.length(&);\
              \n  @each $list in & {\
              \n    list: $list;\
-             \n    length: length($list);\
+             \n    length: list.length($list);\
              \n  }\
              \n}\n"),
         ".test .nest {\
