@@ -16,7 +16,7 @@ fn test() {
              \n  bar: #{($foo*$bar)};\
              \n}\n"
         ),
-        "Error: 10px*in isn\'t a valid CSS value.\
+        "Error: calc(10px * 1in) isn\'t a valid CSS value.\
          \n  ,\
          \n5 |   bar: #{($foo*$bar)};\
          \n  |          ^^^^^^^^^^^\
