@@ -8,12 +8,13 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$color: #1caf9a;\r\
+        runner().ok("@use \"sass:color\";\
+             \n$color: #1caf9a;\r\
              \n\r\
              \nbody {\r\
-             \n  test-01: change-color($color, $hue: -240);\r\
-             \n  test-03: change-color($color, $hue: 120);\r\
-             \n  test-02: change-color($color, $hue: 480);\r\
+             \n  test-01: color.change($color, $hue: -240);\r\
+             \n  test-03: color.change($color, $hue: 120);\r\
+             \n  test-02: color.change($color, $hue: 480);\r\
              \n}"),
         "body {\
          \n  test-01: #1caf1c;\
