@@ -14,12 +14,19 @@ fn test() {
         runner().err(
             "@import \"module\";"
         ),
-        "Error: Top-level selectors may not contain the parent selector \"&\".\
+        "DEPRECATION WARNING [import]: Sass @import rules are deprecated and will be removed in Dart Sass 3.0.0.\n\
+         \nMore info and automated migrator: https://sass-lang.com/d/import\n\
+         \n  ,\
+         \n1 | @import \"module\";\
+         \n  |         ^^^^^^^^\
+         \n  \'\
+         \n    input.scss 1:9  root stylesheet\n\
+         \nError: Top-level selectors may not contain the parent selector \"&\".\
          \n  ,\
          \n1 | .foo, & {\
-         \n  | ^^^^^^^^\
+         \n  |       ^\
          \n  \'\
-         \n  _module.scss 1:1  @import\
+         \n  _module.scss 1:7  @import\
          \n  input.scss 1:9    root stylesheet",
     );
 }
