@@ -6,20 +6,20 @@ fn runner() -> crate::TestRunner {
 }
 
 #[test]
-#[ignore] // unexepected error
 fn test() {
     assert_eq!(
         runner().ok(
-            "$sel1: \'.something__child + .something__child--mod1\';\
+            "@use \"sass:selector\";\
+             \n$sel1: \'.something__child + .something__child--mod1\';\
              \n$sel2: \'.something__child ~ .something__child--mod2\';\
-             \n$result1: selector-unify($sel1, $sel2);\n\
+             \n$result1: selector.unify($sel1, $sel2);\n\
              \n#{$result1} {\
              \n  /* nothing */\
              \n}\n\
              \n.a {\
              \n  color: blue;\
              \n  & > * {\
-             \n    @at-root #{selector-unify(&, \'.b\')} {\
+             \n    @at-root #{selector.unify(&, \'.b\')} {\
              \n      color: red;\
              \n    }\
              \n  }\
@@ -27,7 +27,7 @@ fn test() {
              \n.a, .b {\
              \n  color: blue;\
              \n  & > * {\
-             \n    @at-root #{selector-unify(&, \'.c, .d\')} {\
+             \n    @at-root #{selector.unify(&, \'.c, .d\')} {\
              \n      color: red;\
              \n    }\
              \n  }\
