@@ -8,13 +8,14 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$list: foo bar baz;\
+        runner().ok("@use \"sass:list\";\
+             \n$list: foo bar baz;\
              \n$list--comma: foo, bar, baz;\
              \n$single: foo;\n\
              \ndiv {\
-             \n  _list-space: list-separator($list);\
-             \n  _list-comma: list-separator($list--comma);\
-             \n  _single-item: list-separator($single);\
+             \n  _list-space: list.separator($list);\
+             \n  _list-comma: list.separator($list--comma);\
+             \n  _single-item: list.separator($single);\
              \n}"),
         "div {\
          \n  _list-space: space;\
