@@ -6,12 +6,12 @@ fn runner() -> crate::TestRunner {
 }
 
 #[test]
-#[ignore] // wrong result
+#[ignore] // unexepected error
 fn test() {
     assert_eq!(
         runner().ok(".a ~ x {a: b}\
              \n.b ~ y {@extend x}\n"),
-        ".a ~ x, .a ~ .b ~ y, .b ~ .a ~ y, .b.a ~ y {\
+        ".a ~ x, .a ~ .b ~ y, .b ~ .a ~ y, .a.b ~ y {\
          \n  a: b;\
          \n}\n"
     );
