@@ -9,10 +9,11 @@ fn runner() -> crate::TestRunner {
 fn test() {
     assert_eq!(
         runner().ok(
-            "@mixin import-google-fonts() {\
+            "@use \"sass:string\";\
+             \n@mixin import-google-fonts() {\
              \n  @import url(\"http://fonts.googleapis.com/css?family=#{$family}\");\
              \n}\
-             \n$family: unquote(\"Droid+Sans\");\
+             \n$family: string.unquote(\"Droid+Sans\");\
              \n@include import-google-fonts();\n"
         ),
         "@import url(\"http://fonts.googleapis.com/css?family=Droid+Sans\");\n"
