@@ -11,10 +11,14 @@ fn test() {
     assert_eq!(
         runner().err(".test31#{\'\\@baz\'} { content: \'3.1\'; }\n"),
         "Error: expected selector.\
-         \n  ,\
-         \n1 | .test31@baz{ content: \'3.1\'; }\
-         \n  |        ^\
+         \n  ,--> input.scss\
+         \n1 | .test31#{\'\\@baz\'} { content: \'3.1\'; }\
+         \n  |          ^^^^^^^ \
          \n  \'\
-         \n  input.scss 1:8  root stylesheet",
+         \n  ,\
+         \n1 | .test31@baz \
+         \n  |        = error in interpolated output\
+         \n  \'\
+         \n  input.scss 1:10  root stylesheet",
     );
 }
