@@ -8,28 +8,29 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$x: 2;\n\
+        runner().ok("@use \"sass:list\";\
+             \n@use \"sass:meta\";\
+             \n$x: 2;\n\
              \ndiv {\
              \n  $x: null;\
-             \n  a: length(null null null);\
+             \n  a: list.length(null null null);\
              \n  b: #{null};\
-             \n  d: type-of($x);\
+             \n  d: meta.type-of($x);\
              \n  e: null == null;\
              \n  f: -null;\
              \n  g: -fudge;\
              \n  h: (null null null);\
              \n  i: froo(null, 4);\
              \n  j: (null), (null), 3, 4;\
-             \n  k: length(((null), (null), 3, 4));\
-             \n  \
-             \n  a2: length($x $x $x);\
+             \n  k: list.length(((null), (null), 3, 4));\n\
+             \n  a2: list.length($x $x $x);\
              \n  b2: #{$x};\
              \n  e2: $x == null;\
              \n  f2: -$x;\
              \n  h2: ($x $x $x);\
              \n  i2: froo($x, 4);\
              \n  j2: ($x), ($x), 3, 4;\
-             \n  k2: length((($x), ($x), 3, 4));\
+             \n  k2: list.length((($x), ($x), 3, 4));\
              \n}"),
         "div {\
          \n  a: 3;\
