@@ -9,3 +9,12 @@ mod empty_line {
     #[allow(unused)]
     use super::runner;
 }
+mod error {
+    #[allow(unused)]
+    use super::runner;
+
+    mod mixed_syntax {
+        #[allow(unused)]
+        use super::runner;
+    }
+}
