@@ -8,12 +8,13 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok("$number: 1px * 1rad / 1ms / 1Hz;\
+        runner().ok("@use \"sass:meta\";\
+             \n$number: 1px * 1rad / 1ms / 1Hz;\
              \na {\
-             \n  b: inspect($number / 1px);\
+             \n  b: meta.inspect($number / 1px);\
              \n}\n"),
         "a {\
-         \n  b: 1rad/ms*Hz;\
+         \n  b: calc(1rad / 1ms / 1Hz);\
          \n}\n"
     );
 }
