@@ -8,15 +8,14 @@ fn runner() -> crate::TestRunner {
 #[test]
 fn test() {
     assert_eq!(
-        runner().ok(
-            "// Units cancel even if they\'re totally unknown to Sass.\
+        runner().ok("@use \"sass:meta\";\
+             \n// Units cancel even if they\'re totally unknown to Sass.\
              \n$number: 1foo * 1bar / 1baz / 1qux;\
              \na {\
-             \n  b: inspect($number / 1foo);\
-             \n}\n"
-        ),
+             \n  b: meta.inspect($number / 1foo);\
+             \n}\n"),
         "a {\
-         \n  b: 1bar/baz*qux;\
+         \n  b: calc(1bar / 1baz / 1qux);\
          \n}\n"
     );
 }
