@@ -23,7 +23,6 @@ fn main() -> Result<(), Error> {
         &base,
         "spec",
         &[
-            "core_functions/selector/extend", // not supported
             "directives/extend", // `@extend` is not supported at all
             "libsass-todo-issues/issue_221260.hrx", // stack overflow
             "libsass-todo-issues/issue_221262.hrx", // stack overflow
@@ -539,7 +538,6 @@ fn content(path: &Path) -> Result<String, Error> {
 
 #[derive(Debug)]
 pub struct Error(String);
-use std::convert::From;
 
 impl From<io::Error> for Error {
     fn from(e: io::Error) -> Self {
